@@ -29,18 +29,18 @@
 #include "board.h"
 #include "data.h"
 #include "conf_core.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 #include "plug_io.h"
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/actions.h>
 #include <librnd/core/paths.h>
-#include <librnd/core/hid_menu.h>
+#include <librnd/hid/hid_menu.h>
 #include <librnd/poly/rtree.h>
 #include "undo.h"
 #include "draw.h"
 #include "event.h"
 #include <librnd/core/safe_fs.h>
-#include <librnd/core/tool.h>
+#include <librnd/hid/tool.h>
 #include "layer.h"
 #include "netlist.h"
 
@@ -57,7 +57,7 @@ void pcb_board_free(pcb_board_t * pcb)
 
 	free(pcb->line_mod_merge);
 	free(pcb->hidlib.name);
-	free(pcb->hidlib.filename);
+	free(pcb->hidlib.loadname);
 	free(pcb->PrintFilename);
 	pcb_ratspatch_destroy(pcb);
 	pcb_data_free(pcb->Data);
@@ -97,7 +97,8 @@ pcb_board_t *pcb_board_new_(rnd_bool SetDefaultNames)
 	/* NOTE: we used to set all the pcb flags on ptr here, but we don't need to do that anymore due to the new conf system */
 	ptr->hidlib.grid = rnd_conf.editor.grid;
 
-	ptr->hidlib.size_y = ptr->hidlib.size_x = RND_MM_TO_COORD(20); /* should be overriden by the default design */
+	ptr->hidlib.dwg.Y1 = ptr->hidlib.dwg.X1 = 0;
+	ptr->hidlib.dwg.Y2 = ptr->hidlib.dwg.X2 = RND_MM_TO_COORD(20); /* should be overriden by the default design */
 	ptr->ID = pcb_create_ID_get();
 	ptr->ThermScale = 0.5;
 
@@ -146,10 +147,10 @@ pcb_board_t *pcb_board_new(int inhibit_events)
 
 	if (dpcb == 0) {
 		nw = PCB;
-		if (nw->hidlib.filename != NULL) {
+		if (nw->hidlib.loadname != NULL) {
 			/* make sure the new PCB doesn't inherit the name and loader of the default pcb */
-			free(nw->hidlib.filename);
-			nw->hidlib.filename = NULL;
+			free(nw->hidlib.loadname);
+			nw->hidlib.loadname = NULL;
 			nw->Data->loader = NULL;
 		}
 	}
@@ -250,7 +251,7 @@ void pcb_board_count_slots(pcb_board_t *pcb, int *plated, int *unplated, const r
 
 const char *pcb_board_get_filename(void)
 {
-	return PCB->hidlib.filename;
+	return PCB->hidlib.loadname;
 }
 
 const char *pcb_board_get_name(void)
@@ -262,24 +263,26 @@ rnd_bool pcb_board_change_name(char *Name)
 {
 	free(PCB->hidlib.name);
 	PCB->hidlib.name = Name;
-	pcb_board_changed(0);
+	pcb_board_replaced();
 	return rnd_true;
 }
 
-static void pcb_board_resize_(pcb_board_t *pcb, rnd_coord_t Width, rnd_coord_t Height)
+static void pcb_board_resize_(pcb_board_t *pcb, rnd_coord_t x1, rnd_coord_t y1, rnd_coord_t x2, rnd_coord_t y2)
 {
-	pcb->hidlib.size_x = Width;
-	pcb->hidlib.size_y = Height;
+	pcb->hidlib.dwg.X1 = x1;
+	pcb->hidlib.dwg.Y1 = y1;
+	pcb->hidlib.dwg.X2 = x2;
+	pcb->hidlib.dwg.Y2 = y2;
 
 	if (pcb == PCB)
-		pcb_board_changed(0);
+		pcb_board_replaced();
 }
 
 /*** undoable board resize ***/
 
 typedef struct {
 	pcb_board_t *pcb;
-	rnd_coord_t w, h;
+	rnd_coord_t x1, y1, x2, y2;
 	double thermal_scale;
 } undo_board_size_t;
 
@@ -287,11 +290,12 @@ static int undo_board_size_swap(void *udata)
 {
 	undo_board_size_t *s = udata;
 
-	if ((s->w != s->pcb->hidlib.size_x) || (s->h != s->pcb->hidlib.size_y)) {
-		rnd_coord_t oldw = s->pcb->hidlib.size_x, oldh = s->pcb->hidlib.size_y;
-		pcb_board_resize_(s->pcb, s->w, s->h);
-		s->w = oldw;
-		s->h = oldh;
+	if ((s->x1 != s->pcb->hidlib.dwg.X1) || (s->y1 != s->pcb->hidlib.dwg.Y1) || (s->x2 != s->pcb->hidlib.dwg.X2) || (s->y2 != s->pcb->hidlib.dwg.Y2)) {
+		rnd_coord_t old_x1 = s->pcb->hidlib.dwg.X1, old_y1 = s->pcb->hidlib.dwg.Y1;
+		rnd_coord_t old_x2 = s->pcb->hidlib.dwg.X2, old_y2 = s->pcb->hidlib.dwg.Y2;
+		pcb_board_resize_(s->pcb, s->x1, s->y1, s->x2, s->y2);
+		s->x1 = old_x1; s->y1 = old_y1;
+		s->x2 = old_x2; s->y2 = old_y2;
 	}
 	if (s->thermal_scale != s->pcb->ThermScale) {
 		rnd_swap(double, s->thermal_scale, s->pcb->ThermScale);
@@ -304,8 +308,8 @@ static int undo_board_size_swap(void *udata)
 static void undo_board_size_print(void *udata, char *dst, size_t dst_len)
 {
 	undo_board_size_t *s = udata;
-	if ((s->w != s->pcb->hidlib.size_x) || (s->w != s->pcb->hidlib.size_y))
-		rnd_snprintf(dst, dst_len, "board_size: %mmx%mm ", s->w, s->h);
+	if ((s->x1 != s->pcb->hidlib.dwg.X1) || (s->y1 != s->pcb->hidlib.dwg.Y1) || (s->x2 != s->pcb->hidlib.dwg.X2) || (s->y2 != s->pcb->hidlib.dwg.Y2))
+		rnd_snprintf(dst, dst_len, "board_size: %mm;%mm .. %mm;%mm ", s->x1, s->y1, s->x2, s->y2);
 	if (s->thermal_scale != s->pcb->ThermScale)
 		rnd_snprintf(dst, dst_len, "thermal scale: %f", s->thermal_scale);
 }
@@ -318,19 +322,24 @@ static const uundo_oper_t undo_board_size = {
 	undo_board_size_print
 };
 
-void pcb_board_resize(rnd_coord_t width, rnd_coord_t height, int undoable)
+void pcb_board_resize(rnd_coord_t x1, rnd_coord_t y1, rnd_coord_t x2, rnd_coord_t y2, int undoable)
 {
 	undo_board_size_t *s;
 
 	if (!undoable) {
-		pcb_board_resize_(PCB, width, height);
+		pcb_board_resize_(PCB, x1, y1, x2, y2);
 		return;
 	}
 
+	if ((x1 != 0) || (y1 != 0))
+		rnd_message(RND_MSG_ERROR, "pcb_board_resize(): drawing area should start at 0;0 for compatibility reasons\n");
+
 	s = pcb_undo_alloc(PCB, &undo_board_size, sizeof(undo_board_size_t));
 	s->pcb = PCB;
-	s->w = width;
-	s->h = height;
+	s->x1 = x1;
+	s->y1 = y1;
+	s->x2 = x2;
+	s->y2 = y2;
 	s->thermal_scale = PCB->ThermScale;
 	undo_board_size_swap(s);
 }
@@ -348,8 +357,10 @@ void pcb_board_chg_thermal_scale(double thermal_scale, int undoable)
 
 	s = pcb_undo_alloc(PCB, &undo_board_size, sizeof(undo_board_size_t));
 	s->pcb = PCB;
-	s->w = PCB->hidlib.size_x;
-	s->h = PCB->hidlib.size_y;
+	s->x1 = PCB->hidlib.dwg.X1;
+	s->y1 = PCB->hidlib.dwg.Y1;
+	s->x2 = PCB->hidlib.dwg.X2;
+	s->y2 = PCB->hidlib.dwg.Y2;
 	s->thermal_scale = thermal_scale;
 	undo_board_size_swap(s);
 }
@@ -370,18 +381,16 @@ void pcb_board_set_changed_flag(pcb_board_t *pcb, rnd_bool New)
 	pcb->Changed = New;
 
 	if (old != New)
-		rnd_event(&pcb->hidlib, RND_EVENT_BOARD_META_CHANGED, NULL);
+		rnd_event(&pcb->hidlib, RND_EVENT_DESIGN_META_CHANGED, NULL);
 
 	if (New)
 		rnd_event(&pcb->hidlib, PCB_EVENT_BOARD_EDITED, NULL);
 }
 
 
-void pcb_board_changed(int reverted)
+void pcb_board_replaced(void)
 {
-	if ((rnd_gui != NULL) && (rnd_gui->set_hidlib != NULL))
-		rnd_gui->set_hidlib(rnd_gui, &PCB->hidlib);
-	rnd_event(&PCB->hidlib, RND_EVENT_BOARD_CHANGED, "i", reverted);
+	rnd_single_switch_to(&PCB->hidlib);
 }
 
 int pcb_board_normalize(pcb_board_t *pcb)
@@ -392,13 +401,13 @@ int pcb_board_normalize(pcb_board_t *pcb)
 	if (pcb_data_bbox(&b, pcb->Data, rnd_false) == NULL)
 		return -1;
 
-	if ((b.X2 - b.X1) > pcb->hidlib.size_x) {
-		pcb->hidlib.size_x = b.X2 - b.X1;
+	if ((b.X2 - b.X1) > pcb->hidlib.dwg.X2) {
+		pcb->hidlib.dwg.X2 = b.X2 - b.X1;
 		chg++;
 	}
 
-	if ((b.Y2 - b.Y1) > pcb->hidlib.size_y) {
-		pcb->hidlib.size_y = b.Y2 - b.Y1;
+	if ((b.Y2 - b.Y1) > pcb->hidlib.dwg.Y2) {
+		pcb->hidlib.dwg.Y2 = b.Y2 - b.Y1;
 		chg++;
 	}
 
@@ -461,14 +470,14 @@ rnd_coord_t pcb_board_thickness(pcb_board_t *pcb, const char *namespace, pcb_boa
 	return pcb_stack_thickness(pcb, namespace, flags, 0, rnd_true, pcb->LayerGroups.len-1, rnd_true, PCB_LYT_COPPER | PCB_LYT_SUBSTRATE);
 }
 
-void pcb_board_changed_lib_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+void pcb_board_changed_meta_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
-	pcb_board_changed(1);
+	pcb_board_replaced();
 }
 
 void pcb_board_init(void)
 {
-	rnd_event_bind(RND_EVENT_DESIGN_META_CHANGED_LIB, pcb_board_changed_lib_ev, NULL, core_board_cookie);
+	rnd_event_bind(RND_EVENT_DESIGN_META_CHANGED, pcb_board_changed_meta_ev, NULL, core_board_cookie);
 }
 
 void pcb_board_uninit(void)
