@@ -48,7 +48,7 @@ static const char *EXPERIMENTAL = NULL;
 #include "crosshair.h"
 #include <librnd/core/compat_lrealpath.h>
 #include "polygon.h"
-#include <librnd/core/buildin.hidlib.h>
+#include <librnd/hid/buildin.hidlib.h>
 #include "build_run.h"
 #include <librnd/core/file_loaded.h>
 #include "flag.h"
@@ -60,21 +60,21 @@ static const char *EXPERIMENTAL = NULL;
 #include <librnd/core/funchash.h>
 #include <librnd/core/conf.h>
 #include "conf_core.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 #include <genvector/vtp0.h>
 #include "layer_vis.h"
 #include "layer_ui.h"
 #include "obj_text.h"
 #include "pcb_minuid.h"
-#include <librnd/core/tool.h>
+#include <librnd/hid/tool.h>
 #include <librnd/core/color.h>
 #include "netlist.h"
 #include "extobj.h"
-#include <librnd/core/pixmap.h>
+#include <librnd/hid/pixmap.h>
 
 #include <librnd/core/actions.h>
 #include "actions_pcb.h"
-#include <librnd/core/hid_init.h>
+#include <librnd/hid/hid_init.h>
 #include <librnd/core/compat_misc.h>
 #include "tool_logic.h"
 #include "pixmap_pcb.h"
@@ -90,28 +90,28 @@ static const char *menu_name_fmt = "menu-%s.lht";
 #define CONF_USER_DIR "~/" DOT_PCB_RND
 
 /* for security reasons ignore these nodes when coming from a board or project file */
-static rnd_conf_ignore_t conf_board_ignores[] = {
-	{"rc/action_string", 16, 0},
-	{"rc/library_shell", 16, 0},
-	{"rc/file_command", 15, 0},
-	{"rc/font_command", 15, 0},
-	{"rc/save_command", 15, 0},
-	{"rc/rat_command", 14, 0},
+static rnd_conf_ignore_t conf_prj_dsg_ignores[] = {
+	{"rc/action_string", 16, 0, NULL},
+	{"rc/library_shell", 16, 0, NULL},
+	{"rc/file_command", 15, 0, NULL},
+	{"rc/font_command", 15, 0, NULL},
+	{"rc/save_command", 15, 0, NULL},
+	{"rc/rat_command", 14, 0, NULL},
 	{NULL, 0, 0}
 };
 
 static rnd_conf_ignore_t conf_ignores[] = {
 	/* old config paths - safe to ignore */
-	{"editor/show_mask", 16, 0},
-	{"editor/show_paste", 17, 0},
-	{"editor/increments", 17, 0},
-	{"design/max_width", 16, 0},
-	{"design/max_height", 17, 0},
-	{"design/groups", 13, 1},
-	{"design/default_layer_name", 25, 1},
+	{"editor/show_mask", 16, 0, NULL},
+	{"editor/show_paste", 17, 0, NULL},
+	{"editor/increments", 17, 0, NULL},
+	{"design/max_width", 16, 0, NULL},
+	{"design/max_height", 17, 0, NULL},
+	{"design/groups", 13, 1, NULL},
+	{"design/default_layer_name", 25, 1, NULL},
 
 	/* Do not war for this special case: drc rules create the nodes later */
-	{"design/drc/", 11, 1},
+	{"design/drc/", 11, 1, NULL},
 
 	{NULL, 0, 0}
 };
@@ -167,7 +167,7 @@ static void main_path_init(char *exec_prefix)
 	menu_file_paths[2] = rnd_concat(PCBCONFDIR, "/", NULL);
 	menu_file_paths[3] = NULL;
 
-	rnd_pcbhl_conf_postproc(); /* get ~ (home dir) set */
+	rnd_conf_postproc(); /* get ~ (home dir) set */
 
 	rnd_app.conf_userdir_path = CONF_USER_DIR;
 	rnd_app.conf_user_path = conf_fn_compat(CONF_USER_DIR, "/pcb-conf.lht", "/conf_core.lht");
@@ -402,6 +402,7 @@ int main(int argc, char *argv[])
 	rnd_app.version = PCB_VERSION;
 	rnd_app.revision = PCB_REVISION;
 	rnd_app.url = "http://repo.hu/projects/pcb-rnd";
+	rnd_app.multi_design = 0;
 
 	rnd_app.crosshair_suspend = pcb_crosshair_suspend;
 	rnd_app.crosshair_restore = pcb_crosshair_restore;
@@ -413,7 +414,7 @@ int main(int argc, char *argv[])
 
 	rnd_app.conf_internal = rnd_conf_internal;
 	rnd_app.conf_core_postproc = pcb_conf_core_postproc;
-	rnd_app.conf_board_ignores = conf_board_ignores;
+	rnd_app.conf_prj_dsg_ignores = conf_prj_dsg_ignores;
 	rnd_app.conf_ignores = conf_ignores;
 
 
@@ -440,10 +441,9 @@ int main(int argc, char *argv[])
 	pcb_minuid_init();
 	pcb_extobj_init();
 
-	rnd_hidlib_init1(conf_core_init);
+	rnd_hidlib_init1(conf_core_init, exec_prefix);
 
 	pcb_event_init_app();
-	rnd_conf_set(RND_CFR_INTERNAL, "rc/path/exec_prefix", -1, exec_prefix, RND_POL_OVERWRITE);
 	free(exec_prefix);
 
 	pcb_uilayer_init();
@@ -531,7 +531,7 @@ int main(int argc, char *argv[])
 				exit(1);
 			}
 			/* keep filename if load failed: file might not exist, save it by that name */
-			PCB->hidlib.filename = rnd_strdup(command_line_pcb);
+			PCB->hidlib.loadname = rnd_strdup(command_line_pcb);
 		}
 	}
 
@@ -551,7 +551,7 @@ int main(int argc, char *argv[])
 		rnd_parse_actions(&PCB->hidlib, conf_core.rc.action_string);
 	}
 
-	if (rnd_main_exported(&ga, &PCB->hidlib, pcb_data_is_empty(PCB->Data))) {
+	if (rnd_main_exported(&ga, &PCB->hidlib, pcb_data_is_empty(PCB->Data), NULL)) {
 		pcb_main_uninit();
 		rnd_main_args_uninit(&ga);
 		exit(0);
