@@ -37,7 +37,7 @@
 #include "board.h"
 #include "data.h"
 #include <librnd/core/compat_misc.h>
-#include <librnd/core/hid_inlines.h>
+#include <librnd/hid/hid_inlines.h>
 #include "undo.h"
 #include "polygon.h"
 #include <librnd/poly/offset.h>
@@ -57,7 +57,7 @@
 #include "obj_text_draw.h"
 #include "conf_core.h"
 
-#include <rnd_inclib/font/font.h>
+#include <librnd/font/font.h>
 
 TODO("ui_layer parent fix: remove this")
 #include "layer_ui.h"
@@ -1525,7 +1525,7 @@ static int pcb_text_font_chg_data(pcb_data_t *data, rnd_font_id_t fid)
 	return need_redraw;
 }
 
-static void pcb_text_font_chg(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void pcb_text_font_chg(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 
 	if ((argc < 2) || (argv[1].type != RND_EVARG_INT))
