@@ -650,12 +650,12 @@ static fgw_error_t pcb_act_SavePatch(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	if (fn == NULL) {
 		char *default_file;
 
-		if (PCB->hidlib.filename != NULL) {
+		if (PCB->hidlib.loadname != NULL) {
 			char *end;
 			int len;
-			len = strlen(PCB->hidlib.filename);
+			len = strlen(PCB->hidlib.loadname);
 			default_file = malloc(len + 8);
-			memcpy(default_file, PCB->hidlib.filename, len + 1);
+			memcpy(default_file, PCB->hidlib.loadname, len + 1);
 			end = strrchr(default_file, '.');
 			if ((end == NULL) || (rnd_strcasecmp(end, ".pcb") != 0))
 				end = default_file + len;
@@ -689,7 +689,7 @@ static rnd_action_t rats_patch_action_list[] = {
 	{"SavePatch", pcb_act_SavePatch, pcb_acth_SavePatch, pcb_acts_SavePatch}
 };
 
-static void rats_patch_netlist_chg(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void rats_patch_netlist_chg(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	pcb_rats_patch_cleanup_patches((pcb_board_t *)hidlib);
 }
