@@ -49,6 +49,9 @@
 #include "obj_subc_parent.h"
 #include "obj_pstk_inlines.h"
 
+#define PCB_MAX_POLYGON_POINT_DISTANCE  0   /* maximum distance when searching polygon points */
+#define PCB_MAX_LINE_POINT_DISTANCE     0   /* maximum distance when searching line points; same for arc point */
+
 static double PosX, PosY;				/* search position for subroutines */
 static rnd_coord_t SearchRadius;
 static rnd_box_t SearchBox;
@@ -61,7 +64,7 @@ static pcb_layer_t *SearchLayer;
  */
 static rnd_bool SearchLineByLocation(unsigned long, unsigned long, pcb_layer_t **, pcb_line_t **, pcb_line_t **);
 static rnd_bool SearchArcByLocation(unsigned long, unsigned long, pcb_layer_t **, pcb_arc_t **, pcb_arc_t **);
-static rnd_bool SearchGfxByLocation(unsigned long, unsigned long, pcb_layer_t **, pcb_gfx_t **, pcb_gfx_t **);
+static rnd_bool SearchGfxByLocation(unsigned long, unsigned long, pcb_layer_t **, pcb_gfx_t **, pcb_gfx_t **, int);
 static rnd_bool SearchRatLineByLocation(unsigned long, unsigned long, pcb_rat_t **, pcb_rat_t **, pcb_rat_t **);
 static rnd_bool SearchTextByLocation(unsigned long, unsigned long, pcb_layer_t **, pcb_text_t **, pcb_text_t **);
 static rnd_bool SearchPolygonByLocation(unsigned long, unsigned long, pcb_layer_t **, pcb_poly_t **, pcb_poly_t **);
@@ -268,6 +271,7 @@ struct gfx_info {
 	pcb_gfx_t **Gfx, **Dummy;
 	unsigned long objst, req_flag;
 	double least;
+	int level;
 };
 
 static rnd_r_dir_t gfx_callback(const rnd_box_t *box, void *cl)
@@ -277,6 +281,10 @@ static rnd_r_dir_t gfx_callback(const rnd_box_t *box, void *cl)
 
 	TEST_OBJST(i->objst, i->req_flag, l, g, g);
 
+	/* cheap: ignore gfx if it doesn't match requested rendering level */
+	if ((i->level < 0) && !g->render_under) return 0;
+	if ((i->level > 0) && g->render_under) return 0;
+
 	if (!pcb_is_point_in_gfx(PosX, PosY, SearchRadius, g))
 		return 0;
 	*i->Gfx = g;
@@ -284,7 +292,9 @@ static rnd_r_dir_t gfx_callback(const rnd_box_t *box, void *cl)
 	return RND_R_DIR_CANCEL; /* found */
 }
 
-static rnd_bool SearchGfxByLocation(unsigned long objst, unsigned long req_flag, pcb_layer_t **Layer, pcb_gfx_t **gfx, pcb_gfx_t **Dummy)
+/* level: -1 returns only "render_under", +1 returns only render-above, 0
+   returns anything */
+static rnd_bool SearchGfxByLocation(unsigned long objst, unsigned long req_flag, pcb_layer_t **Layer, pcb_gfx_t **gfx, pcb_gfx_t **Dummy, int level)
 {
 	struct gfx_info info;
 
@@ -292,6 +302,7 @@ static rnd_bool SearchGfxByLocation(unsigned long objst, unsigned long req_flag,
 	info.Dummy = Dummy;
 	info.objst = objst;
 	info.req_flag = req_flag;
+	info.level = level;
 
 	*Layer = SearchLayer;
 	if (rnd_r_search(SearchLayer->gfx_tree, &SearchBox, NULL, gfx_callback, &info, NULL) != RND_R_DIR_NOT_FOUND)
@@ -437,7 +448,7 @@ static rnd_bool SearchLinePointByLocation(unsigned long objst, unsigned long req
 	info.Line = Line;
 	info.Point = Point;
 	*Point = NULL;
-	info.least = RND_MAX_LINE_POINT_DISTANCE + SearchRadius;
+	info.least = PCB_MAX_LINE_POINT_DISTANCE + SearchRadius;
 	info.objst = objst;
 	info.req_flag = req_flag;
 
@@ -456,7 +467,7 @@ static rnd_bool SearchArcPointByLocation(unsigned long objst, unsigned long req_
 	info.Arc = Arc;
 	info.arc_pt = Point;
 	*Point = NULL;
-	info.least = RND_MAX_LINE_POINT_DISTANCE + SearchRadius;
+	info.least = PCB_MAX_LINE_POINT_DISTANCE + SearchRadius;
 	info.objst = objst;
 	info.req_flag = req_flag;
 
@@ -521,7 +532,7 @@ static rnd_bool SearchPointByLocation(unsigned long Type, unsigned long objst, u
 	ctx.Polygon = Polygon;
 	ctx.Point = Point;
 	ctx.found = rnd_false;;
-	ctx.least = SearchRadius + RND_MAX_POLYGON_POINT_DISTANCE;
+	ctx.least = SearchRadius + PCB_MAX_POLYGON_POINT_DISTANCE;
 	ctx.least = ctx.least * ctx.least;
 	rnd_r_search(SearchLayer->polygon_tree, &SearchBox, NULL, polypoint_callback, &ctx, NULL);
 
@@ -585,7 +596,7 @@ static rnd_bool SearchGfxPointByLocation(unsigned long Type, unsigned long objst
 	ctx.gfx = gfx;
 	ctx.Point = Point;
 	ctx.found = rnd_false;;
-	ctx.least = SearchRadius + RND_MAX_POLYGON_POINT_DISTANCE;
+	ctx.least = SearchRadius + PCB_MAX_POLYGON_POINT_DISTANCE;
 	ctx.least = ctx.least * ctx.least;
 	rnd_r_search(SearchLayer->gfx_tree, &SearchBox, NULL, gfxpoint_callback, &ctx, NULL);
 
@@ -1300,9 +1311,16 @@ pcb_layer_type_t pstk_vis_layers(pcb_board_t *pcb, pcb_layer_type_t material)
 	return res | material;
 }
 
+/* Ignores render-below gfx objects */
 static int pcb_search_obj_by_loc_layer(unsigned long Type, void **Result1, void **Result2, void **Result3, unsigned long req_flag, pcb_layer_t *SearchLayer, int HigherAvail, double HigherBound, int objst)
 {
 	if (SearchLayer->meta.real.vis) {
+		/* GFX searched first because if it is rendered above, it is visible over
+		   the others */
+		if ((HigherAvail & (PCB_OBJ_PSTK)) == 0 && Type & PCB_OBJ_GFX &&
+				SearchGfxByLocation(objst, req_flag, (pcb_layer_t **)Result1, (pcb_gfx_t **)Result2, (pcb_gfx_t **)Result3, +1))
+			return PCB_OBJ_GFX;
+
 		if ((HigherAvail & (PCB_OBJ_PSTK)) == 0 &&
 				Type & PCB_OBJ_GFX_POINT &&
 				SearchGfxPointByLocation(Type, objst, req_flag, (pcb_layer_t **) Result1, (pcb_gfx_t **) Result2, (rnd_point_t **) Result3))
@@ -1349,14 +1367,22 @@ static int pcb_search_obj_by_loc_layer(unsigned long Type, void **Result1, void
 				return PCB_OBJ_POLY;
 		}
 
-		if ((HigherAvail & (PCB_OBJ_PSTK)) == 0 && Type & PCB_OBJ_GFX &&
-				SearchGfxByLocation(objst, req_flag, (pcb_layer_t **)Result1, (pcb_gfx_t **)Result2, (pcb_gfx_t **)Result3))
-			return PCB_OBJ_GFX;
 
 	}
 	return 0;
 }
 
+/* Searches only for render_below gfx objects on the given layer */
+static int pcb_search_by_loc_below_gfx(unsigned long Type, void **Result1, void **Result2, void **Result3, unsigned long req_flag, pcb_layer_t *SearchLayer, int HigherAvail, double HigherBound, int objst)
+{
+	if (SearchLayer->meta.real.vis) {
+		if ((HigherAvail & (PCB_OBJ_PSTK)) == 0 && Type & PCB_OBJ_GFX &&
+				SearchGfxByLocation(objst, req_flag, (pcb_layer_t **)Result1, (pcb_gfx_t **)Result2, (pcb_gfx_t **)Result3, -1))
+			return PCB_OBJ_GFX;
+	}
+	return 0;
+}
+
 static int pcb_search_obj_by_loc_group(unsigned long Type, void **Result1, void **Result2, void **Result3, unsigned long req_flag, const pcb_layergrp_t *grp, int HigherAvail, double HigherBound, int objst)
 {
 	rnd_cardinal_t n;
@@ -1530,6 +1556,17 @@ static int pcb_search_obj_by_location_(unsigned long Type, void **Result1, void
 			SearchSubcByLocation(objst, req_flag, (pcb_subc_t **) Result1, (pcb_subc_t **) Result2, (pcb_subc_t **) Result3, rnd_true))
 		return PCB_OBJ_SUBC;
 
+	/* render-below gfx objects last, as they are surely under anything else */
+	for(i = 0; i < pcb_max_layer(PCB); i++) {
+		int found;
+		SearchLayer = PCB_STACKLAYER(PCB, i);
+		found = pcb_search_by_loc_below_gfx(Type, Result1, Result2, Result3, req_flag, SearchLayer, HigherAvail, HigherBound, objst);
+		if (found < 0)
+			break;
+		if (found != 0)
+			return found;
+	}
+
 	return PCB_OBJ_VOID;
 }
 
@@ -1768,6 +1805,7 @@ int pcb_search_grid_slop(rnd_coord_t X, rnd_coord_t Y, int Type, void **Result1,
 }
 
 vtp0_t pcb_obj_list_vect;
+pcb_board_t *pcb_obj_list_board;
 int pcb_search_screen_selector(rnd_coord_t X, rnd_coord_t Y, int Type, void **Result1, void **Result2, void **Result3)
 {
 	rnd_box_t box;
@@ -1784,6 +1822,7 @@ int pcb_search_screen_selector(rnd_coord_t X, rnd_coord_t Y, int Type, void **Re
 	box.Y1 = Y + radius;
 
 	vtp0_init(&pcb_obj_list_vect);
+	pcb_obj_list_board = PCB;
 	pcb_list_block_cb(PCB, &box, (void *(*)(void *, pcb_any_obj_t *))vtp0_append, &pcb_obj_list_vect);
 
 	if (pcb_obj_list_vect.used == 1) {
@@ -1800,10 +1839,12 @@ int pcb_search_screen_selector(rnd_coord_t X, rnd_coord_t Y, int Type, void **Re
 	}
 
 	vtp0_uninit(&pcb_obj_list_vect);
+	pcb_obj_list_board = NULL;
 	return PCB_OBJ_VOID;
 
 	found:;
 	vtp0_uninit(&pcb_obj_list_vect);
+	pcb_obj_list_board = NULL;
 	*Result1 = obj->parent.any;
 	*Result2 = *Result3 = obj;
 	return obj->type;
