@@ -27,7 +27,7 @@
 #include "event.h"
 #include "netlist.h"
 #include <genvector/vtp0.h>
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 
 const char *dlg_netlist_cookie = "netlist dialog";
 
@@ -224,12 +224,12 @@ static void netlist_update_len_by_row(netlist_ctx_t *ctx, rnd_hid_row_t *row)
 	if (nlres.type == FGW_COORD) {
 		char tmp[128];
 		rnd_snprintf(tmp, sizeof(tmp), "%$m*", rnd_conf.editor.grid_unit->suffix, fgw_coord(&nlres));
-		rnd_dad_tree_modify_cell(atree, row, 3, tmp);
+		rnd_dad_tree_modify_cell(atree, row, 3, rnd_strdup(tmp));
 	}
 	else if ((nlres.type & FGW_STR) == FGW_STR)
-		rnd_dad_tree_modify_cell(atree, row, 3, nlres.val.str);
+		rnd_dad_tree_modify_cell(atree, row, 3, rnd_strdup(nlres.val.str));
 	else
-		rnd_dad_tree_modify_cell(atree, row, 3, "invalid return");
+		rnd_dad_tree_modify_cell(atree, row, 3, rnd_strdup("invalid return"));
 }
 
 #if 0
@@ -353,7 +353,7 @@ static void netlist_len_refresh_cb(void *hid_ctx, void *caller_data, rnd_hid_att
 
 static vtp0_t netlist_color_save;
 
-static void netlist_expose(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void netlist_expose(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 	netlist_ctx_t *ctx = prv->user_ctx;
 	rnd_xform_t xform;
@@ -388,6 +388,7 @@ static void netlist_expose(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv,
 	/* draw the board */
 	memset(&xform, 0, sizeof(xform));
 	xform.layer_faded = 1;
+	e->design = &ctx->pcb->hidlib;
 	rnd_app.expose_main(rnd_gui, e, &xform);
 
 	if (net != NULL) {/* restore object color */
@@ -416,17 +417,16 @@ static void pcb_dlg_netlist(pcb_board_t *pcb)
 	if (netlist_ctx.active)
 		return; /* do not open another */
 
-	netlist_ctx.bb_prv.X1 = 0;
-	netlist_ctx.bb_prv.Y1 = 0;
-	netlist_ctx.bb_prv.X2 = pcb->hidlib.size_x;
-	netlist_ctx.bb_prv.Y2 = pcb->hidlib.size_y;
+	netlist_ctx.bb_prv.X1 = pcb->hidlib.dwg.X1;
+	netlist_ctx.bb_prv.Y1 = pcb->hidlib.dwg.Y1;
+	netlist_ctx.bb_prv.X2 = pcb->hidlib.dwg.X2;
+	netlist_ctx.bb_prv.Y2 = pcb->hidlib.dwg.Y2;
 	netlist_ctx.pcb = pcb;
 
 	RND_DAD_BEGIN_VBOX(netlist_ctx.dlg); /* layout */
 		RND_DAD_COMPFLAG(netlist_ctx.dlg, RND_HATF_EXPFILL);
 
-		RND_DAD_BEGIN_HPANE(netlist_ctx.dlg);
-			RND_DAD_SET_PANE_NAME(netlist_ctx.dlg, "left-right");
+		RND_DAD_BEGIN_HPANE(netlist_ctx.dlg, "left-right");
 			RND_DAD_COMPFLAG(netlist_ctx.dlg, RND_HATF_EXPFILL);
 			whpan = RND_DAD_CURRENT(netlist_ctx.dlg);
 
@@ -441,14 +441,13 @@ static void pcb_dlg_netlist(pcb_board_t *pcb)
 
 			RND_DAD_BEGIN_VBOX(netlist_ctx.dlg); /* right */
 				RND_DAD_COMPFLAG(netlist_ctx.dlg, RND_HATF_EXPFILL);
-				RND_DAD_BEGIN_VPANE(netlist_ctx.dlg);
-					RND_DAD_SET_PANE_NAME(netlist_ctx.dlg, "top-bottom");
+				RND_DAD_BEGIN_VPANE(netlist_ctx.dlg, "top-bottom");
 					RND_DAD_COMPFLAG(netlist_ctx.dlg, RND_HATF_EXPFILL);
 					wvpan = RND_DAD_CURRENT(netlist_ctx.dlg);
 					RND_DAD_BEGIN_VBOX(netlist_ctx.dlg); /* right-top */
 						RND_DAD_COMPFLAG(netlist_ctx.dlg, RND_HATF_EXPFILL);
 						RND_DAD_PREVIEW(netlist_ctx.dlg, netlist_expose, netlist_mouse, NULL, NULL, &netlist_ctx.bb_prv, 100, 100, &netlist_ctx);
-							RND_DAD_COMPFLAG(netlist_ctx.dlg, RND_HATF_EXPFILL | RND_HATF_PRV_BOARD);
+							RND_DAD_COMPFLAG(netlist_ctx.dlg, RND_HATF_EXPFILL | RND_HATF_PRV_DESIGN);
 							netlist_ctx.wprev = RND_DAD_CURRENT(netlist_ctx.dlg);
 					RND_DAD_END(netlist_ctx.dlg);
 					RND_DAD_BEGIN_VBOX(netlist_ctx.dlg); /* right-bottom */
@@ -612,7 +611,7 @@ static fgw_error_t pcb_act_NetlistDialog(fgw_arg_t *res, int argc, fgw_arg_t *ar
 }
 
 /* update the dialog after a netlist change */
-static void pcb_dlg_netlist_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void pcb_dlg_netlist_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	netlist_ctx_t *ctx = user_data;
 	if (!ctx->active)
