@@ -33,15 +33,15 @@
 #include <librnd/core/actions.h>
 #include "board.h"
 #include "conf_core.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 #include "view.h"
 #include "draw.h"
 #include "drc.h"
 #include "actions_pcb.h"
 #include <librnd/core/event.h>
-#include <librnd/core/hid_inlines.h>
-#include <librnd/core/hid_dad.h>
-#include <librnd/core/hid_dad_tree.h>
+#include <librnd/hid/hid_inlines.h>
+#include <librnd/hid/hid_dad.h>
+#include <librnd/hid/hid_dad_tree.h>
 #include "undo.h"
 #include <librnd/core/safe_fs.h>
 #include <librnd/core/misc_util.h>
@@ -203,7 +203,7 @@ static void view_select(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_hid_row_
 
 static vtp0_t view_color_save;
 
-static void view_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void view_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 	view_ctx_t *ctx = prv->user_ctx;
 	rnd_xform_t xform;
@@ -243,6 +243,7 @@ static void view_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv,
 	pcb_draw_force_termlab = 1;
 	memset(&xform, 0, sizeof(xform));
 	xform.layer_faded = 1;
+	e->design = &ctx->pcb->hidlib;
 	rnd_app.expose_main(rnd_gui, e, &xform);
 	pcb_draw_force_termlab = old_termlab;
 
@@ -382,7 +383,7 @@ static void view_copy_btn_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute
 		}
 	}
 	pcb_view_save_list_end(&tmp, NULL);
-	rnd_gui->clip_set(rnd_gui, RND_HID_CLIPFMT_TEXT, tmp.array, tmp.used+1);
+	rnd_gui->clip_set(rnd_gui, tmp.array);
 	gds_uninit(&tmp);
 	if (cut)
 		view2dlg_list(ctx);
@@ -391,9 +392,8 @@ static void view_copy_btn_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute
 static void view_paste_btn_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr_btn)
 {
 	view_ctx_t *ctx = caller_data;
-	rnd_hid_clipfmt_t cformat;
-	void *cdata, *load_ctx;
-	size_t clen;
+	char *cdata;
+	void *load_ctx;
 	pcb_view_t *v, *vt = NULL;
 	rnd_hid_attribute_t *attr = &ctx->dlg[ctx->wlist];
 	rnd_hid_row_t *r = rnd_dad_tree_get_selected(attr);
@@ -408,16 +408,12 @@ static void view_paste_btn_cb(void *hid_ctx, void *caller_data, rnd_hid_attribut
 		vt = pcb_view_by_uid(ctx->lst, r->user_data2.lng);
 	}
 
-	if (rnd_gui->clip_get(rnd_gui, &cformat, &cdata, &clen) != 0)
+	cdata = rnd_gui->clip_get(rnd_gui);
+	if (cdata == NULL)
 		return;
 
-	if (cformat != RND_HID_CLIPFMT_TEXT) {
-		rnd_gui->clip_free(rnd_gui, cformat, cdata, clen);
-		return;
-	}
-
 	load_ctx = pcb_view_load_start_str(cdata);
-	rnd_gui->clip_free(rnd_gui, cformat, cdata, clen);
+	free(cdata);
 	if (load_ctx == NULL)
 		return;
 
@@ -592,8 +588,7 @@ static void pcb_dlg_view_full(const char *id, view_ctx_t *ctx, const char *title
 	RND_DAD_BEGIN_VBOX(ctx->dlg);
 		RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
 
-		RND_DAD_BEGIN_HPANE(ctx->dlg);
-			RND_DAD_SET_PANE_NAME(ctx->dlg, "left-right");
+		RND_DAD_BEGIN_HPANE(ctx->dlg, "left-right");
 			RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
 
 			/* left */
@@ -632,7 +627,7 @@ static void pcb_dlg_view_full(const char *id, view_ctx_t *ctx, const char *title
 				RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
 				RND_DAD_PREVIEW(ctx->dlg, view_expose_cb, view_mouse_cb, NULL, NULL, NULL, 100, 100, ctx);
 					ctx->wprev = RND_DAD_CURRENT(ctx->dlg);
-					RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL | RND_HATF_PRV_BOARD | preview_flipflags);
+					RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL | RND_HATF_PRV_DESIGN | preview_flipflags);
 				RND_DAD_LABEL(ctx->dlg, "(description)");
 					ctx->wdescription = RND_DAD_CURRENT(ctx->dlg);
 				RND_DAD_LABEL(ctx->dlg, "(measure)");
@@ -679,7 +674,7 @@ static void pcb_dlg_view_simplified(const char *id, view_ctx_t *ctx, const char
 			RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
 			RND_DAD_PREVIEW(ctx->dlg, view_expose_cb, view_mouse_cb, NULL, NULL, NULL, 100, 100, ctx);
 				ctx->wprev = RND_DAD_CURRENT(ctx->dlg);
-				RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL | RND_HATF_PRV_BOARD | preview_flipflags);
+				RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL | RND_HATF_PRV_DESIGN | preview_flipflags);
 			RND_DAD_BEGIN_VBOX(ctx->dlg);
 				RND_DAD_LABEL(ctx->dlg, "(description)");
 					ctx->wdescription = RND_DAD_CURRENT(ctx->dlg);
@@ -826,12 +821,12 @@ fgw_error_t pcb_act_ViewList(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		ctx->lst = calloc(sizeof(pcb_view_list_t), 1);
 	ctx->list_alloced = 1;
 	ctx->refresh = NULL;
-	pcb_dlg_view_full(winid, ctx, name, NULL, 0);
+	pcb_dlg_view_full(winid, ctx, name, NULL, RND_HATF_PRV_GFLIP);
 	view2dlg(ctx);
 	return 0;
 }
 
-static void view_preview_update_cb(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void view_preview_update_cb(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	if (drc_gui_ctx.active)
 		view_preview_update(&drc_gui_ctx);
