@@ -28,8 +28,8 @@
  *
  */
 
-#include <librnd/core/hid_dad.h>
-#include <librnd/core/hid_dad_tree.h>
+#include <librnd/hid/hid_dad.h>
+#include <librnd/hid/hid_dad_tree.h>
 #include <genlist/gendlist.h>
 #include "actions_pcb.h"
 
@@ -145,7 +145,7 @@ static int drc_query_progress(pcb_qry_exec_t *ec, long at, long total)
 
 	if (prog->qctx != NULL) {
 		sprintf(tmp, "%ld", prog->qctx->hit_cnt);
-		hv.str = rnd_strdup(tmp);
+		hv.str = tmp;
 		rnd_gui->attr_dlg_set_value(pb->dlg_hid_ctx, pb->wcnt, &hv);
 	}
 
@@ -209,7 +209,7 @@ static void drc_rule_pcb2dlg(rule_edit_ctx_t *ctx)
 	}
 }
 
-static void drcq_open_view_win(rnd_hidlib_t *hidlib, pcb_view_list_t *view)
+static void drcq_open_view_win(rnd_design_t *hidlib, pcb_view_list_t *view)
 {
 	fgw_arg_t args[4], ares;
 	args[1].type = FGW_STR; args[1].val.str = "drc_query: manual run";
@@ -226,7 +226,7 @@ static void rule_btn_run_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_
 	rnd_hid_text_t *txt = atxt->wdata;
 	char *script = txt->hid_get_text(atxt, hid_ctx);
 	pcb_view_list_t *view = calloc(sizeof(pcb_view_list_t), 1);
-	pcb_board_t *pcb = (pcb_board_t *)rnd_gui->get_dad_hidlib(hid_ctx);
+	pcb_board_t *pcb = (pcb_board_t *)rnd_gui->get_dad_design(hid_ctx);
 	pcb_qry_exec_t ec;
 
 	pcb_qry_init(&ec, pcb, NULL, -1);
@@ -477,9 +477,9 @@ static void drc_rlist_pcb2dlg(void)
 
 		role = rnd_conf_lookup_role(rule);
 		src = textval_empty(rule, "source");
-		cell[0] = rule->name;
+		cell[0] = rnd_strdup(rule->name);
 		cell[1] = rnd_strdup(rnd_conf_role_name(role));
-		cell[2] = *dis ? "YES" : "no";
+		cell[2] = rnd_strdup(*dis ? "YES" : "no");
 		if (st->run_cnt > 0)
 			cell[3] = rnd_strdup_printf("%.3fs", st->last_run_time);
 		else
@@ -491,10 +491,10 @@ static void drc_rlist_pcb2dlg(void)
 			char *pcell[5];
 
 			if (parent == NULL) {
-				pcell[0] = (char *)src;
-				pcell[1] = "";
-				pcell[2] = "";
-				pcell[3] = "";
+				pcell[0] = rnd_strdup(src);
+				pcell[1] = rnd_strdup("");
+				pcell[2] = rnd_strdup("");
+				pcell[3] = rnd_strdup("");
 				pcell[4] = NULL;
 				parent = rnd_dad_tree_append(tree->attrib, NULL, pcell);
 			}
@@ -541,7 +541,7 @@ static void rlist_btn_remove_cb(void *hid_ctx, void *caller_data, rnd_hid_attrib
 {
 	drc_rlist_ctx_t *ctx = caller_data;
 	rnd_hid_row_t *row = rnd_dad_tree_get_selected(&(ctx->dlg[ctx->wrlist]));
-	pcb_board_t *pcb = (pcb_board_t *)rnd_gui->get_dad_hidlib(hid_ctx);
+	pcb_board_t *pcb = (pcb_board_t *)rnd_gui->get_dad_design(hid_ctx);
 	rnd_conf_role_t role;
 
 	if (row == NULL) {
@@ -635,7 +635,7 @@ static void rlist_btn_run_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute
 	const char *script;
 	rnd_conf_role_t role;
 	pcb_view_list_t *view;
-	pcb_board_t *pcb = (pcb_board_t *)rnd_gui->get_dad_hidlib(hid_ctx);
+	pcb_board_t *pcb = (pcb_board_t *)rnd_gui->get_dad_design(hid_ctx);
 	pcb_qry_exec_t ec;
 
 	rlist_fetch();
@@ -659,7 +659,7 @@ static void rlist_btn_export_cb(void *hid_ctx, void *caller_data, rnd_hid_attrib
 {
 	drc_rlist_ctx_t *ctx = caller_data;
 	rnd_hid_row_t *row = rnd_dad_tree_get_selected(&(ctx->dlg[ctx->wrlist]));
-	pcb_board_t *pcb = (pcb_board_t *)rnd_gui->get_dad_hidlib(hid_ctx);
+	pcb_board_t *pcb = (pcb_board_t *)rnd_gui->get_dad_design(hid_ctx);
 
 	if (row == NULL) {
 		rnd_message(RND_MSG_ERROR, "Select a rule first\n");
@@ -671,7 +671,7 @@ static void rlist_btn_export_cb(void *hid_ctx, void *caller_data, rnd_hid_attrib
 
 static void rlist_btn_import_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr_inp)
 {
-	pcb_board_t *pcb = (pcb_board_t *)rnd_gui->get_dad_hidlib(hid_ctx);
+	pcb_board_t *pcb = (pcb_board_t *)rnd_gui->get_dad_design(hid_ctx);
 
 	rnd_actionva(&pcb->hidlib, "DrcQueryImport", NULL);
 	drc_rlist_pcb2dlg();
@@ -775,7 +775,7 @@ static void drc_dlist_pcb2dlg(void)
 
 		role = rnd_conf_lookup_role(rule);
 		src = textval_empty(rule, "source");
-		cell[0] = rule->name;
+		cell[0] = rnd_strdup(rule->name);
 		cell[1] = rnd_strdup(rnd_conf_role_name(role));
 
 		if (*src != '\0') {
@@ -784,8 +784,8 @@ static void drc_dlist_pcb2dlg(void)
 			char *pcell[3];
 
 			if (parent == NULL) {
-				pcell[0] = (char *)src;
-				pcell[1] = "";
+				pcell[0] = rnd_strdup(src);
+				pcell[1] = rnd_strdup("");
 				pcell[2] = NULL;
 				parent = rnd_dad_tree_append(tree->attrib, NULL, pcell);
 			}
@@ -811,7 +811,7 @@ static void dlist_btn_edit_cb(void *hid_ctx, void *caller_data, rnd_hid_attribut
 {
 	drc_rlist_ctx_t *ctx = caller_data;
 	rnd_hid_row_t *row = rnd_dad_tree_get_selected(&(ctx->dlg[ctx->wdlist]));
-	rnd_hidlib_t *hl = rnd_gui->get_dad_hidlib(hid_ctx);
+	rnd_design_t *hl = rnd_gui->get_dad_design(hid_ctx);
 	lht_node_t *nd;
 	char *path;
 
@@ -898,8 +898,7 @@ static void pcb_dlg_drc_rlist_rules(int *wpane)
 {
 	static const char *lst_hdr[] = {"rule name", "role", "disabled", "cost", NULL};
 
-	RND_DAD_BEGIN_HPANE(drc_rlist_ctx.dlg);
-		RND_DAD_SET_PANE_NAME(drc_rlist_ctx.dlg, "rule-left-right");
+	RND_DAD_BEGIN_HPANE(drc_rlist_ctx.dlg, "rule-left-right");
 		*wpane = RND_DAD_CURRENT(drc_rlist_ctx.dlg);
 
 		RND_DAD_BEGIN_VBOX(drc_rlist_ctx.dlg); /* left */
@@ -961,8 +960,7 @@ static void pcb_dlg_drc_rlist_defs(int *wpane)
 {
 	static const char *lst_hdr[] = {"rule name", "role", NULL};
 
-	RND_DAD_BEGIN_HPANE(drc_rlist_ctx.dlg);
-		RND_DAD_SET_PANE_NAME(drc_rlist_ctx.dlg, "def-left-right");
+	RND_DAD_BEGIN_HPANE(drc_rlist_ctx.dlg, "def-left-right");
 		*wpane = RND_DAD_CURRENT(drc_rlist_ctx.dlg);
 
 		RND_DAD_BEGIN_VBOX(drc_rlist_ctx.dlg); /* left */
