@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  pcb-rnd, interactive printed circuit board design
- *  Copyright (C) 2017,2020 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2017,2020,2023 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,6 +40,7 @@
 #include <librnd/core/compat_misc.h>
 #include "board.h"
 #include "data.h"
+#include "data_it.h"
 #include "draw.h"
 #include <librnd/core/error.h>
 #include "layer.h"
@@ -81,6 +82,8 @@ static int scad_group_level;
 static const char *scad_group_color;
 static int scad_layer_cnt;
 static vti0_t scad_comp;
+static const char *scad_prefix = "pcb";
+static double board_thickness = 1.6;
 
 static rnd_hid_attr_val_t *openscad_options;
 
@@ -114,13 +117,17 @@ Name of the file to be exported to. Can contain a path.
 	 RND_HATT_BOOL, 0, 0, {1, 0, 0}, 0},
 #define HA_models 4
 
+	{"prefix", "prefix for module names so that multiple exports can be used together",
+	 RND_HATT_STRING, 0, 0, {0, "pcb", 0}, 0},
+#define HA_prefix 5
+
 	{"drill", "enable drilling holes",
 	 RND_HATT_BOOL, 0, 0, {1, 0, 0}, 0},
-#define HA_drill 5
+#define HA_drill 6
 
 	{"cam", "CAM instruction",
 	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
-#define HA_cam 6
+#define HA_cam 7
 
 };
 
@@ -218,7 +225,7 @@ static void scad_dump_comp(void)
 		int id = scad_comp.array[n], is_pos = id > 0;
 		if (id < 0)
 			id = -id;
-		fprintf(f, "	layer_%s_%s_%d();\n", scad_group_name, is_pos ? "pos" : "neg", id);
+		fprintf(f, "	%s_layer_%s_%s_%d();\n", scad_prefix , scad_group_name, is_pos ? "pos" : "neg", id);
 		if ((n > 0) && (n < vti0_len(&scad_comp)-1)) {
 			int id2 = scad_comp.array[n+1];
 			int p1 = is_pos, p2 = (id2 > 0);
@@ -237,11 +244,11 @@ static void scad_dump_comp(void)
 static void scad_close_layer_group()
 {
 	if (scad_group_name != NULL) {
-		fprintf(f, "module layer_group_%s() {\n", scad_group_name);
+		fprintf(f, "module %s_layer_group_%s() {\n", scad_prefix, scad_group_name);
 		scad_dump_comp();
 		fprintf(f, "}\n\n");
 
-		rnd_append_printf(&layer_group_calls, "	layer_group_%s();\n", scad_group_name);
+		rnd_append_printf(&layer_group_calls, "	%s_layer_group_%s();\n", scad_prefix, scad_group_name);
 		scad_group_name = NULL;
 		scad_group_color = NULL;
 		scad_group_level = 0;
@@ -264,21 +271,21 @@ static void scad_new_layer(int is_pos)
 	if (is_pos) {
 		effective_layer_thickness = layer_thickness;
 		if (scad_group_level > 0)
-			h = 0.8+((double)scad_group_level*1.1) * effective_layer_thickness;
+			h = board_thickness/2.0+((double)scad_group_level*1.1) * effective_layer_thickness;
 		else
-			h = -0.8+((double)scad_group_level*1.1) * effective_layer_thickness;
+			h = -board_thickness/2.0+((double)scad_group_level*1.1) * effective_layer_thickness;
 	}
 	else {
 		double mult = 2.0;
 		effective_layer_thickness = layer_thickness * mult;
 		if (scad_group_level > 0)
-			h = 0.8+((double)scad_group_level*1.1) * layer_thickness;
+			h = board_thickness/2.0+((double)scad_group_level*1.1) * layer_thickness;
 		else
-			h = -0.8+((double)scad_group_level*1.1) * layer_thickness;
+			h = -board_thickness/2.0+((double)scad_group_level*1.1) * layer_thickness;
 		h -= effective_layer_thickness/2.0;
 		effective_layer_thickness+=1.0;
 	}
-	fprintf(f, "module layer_%s_%s_%d() {\n", scad_group_name, is_pos ? "pos" : "neg", scad_layer_cnt);
+	fprintf(f, "module %s_layer_%s_%s_%d() {\n", scad_prefix, scad_group_name, is_pos ? "pos" : "neg", scad_layer_cnt);
 	fprintf(f, "	color([%s])\n", scad_group_color);
 	fprintf(f, "		translate([0,0,%f]) {\n", h);
 	layer_open = 1;
@@ -296,12 +303,29 @@ static void scad_new_layer_group(const char *group_name, int level, const char *
 	scad_group_level = level;
 }
 
+/* Find the pick and place 0;0 mark, if there is any */
+static void find_origin(rnd_coord_t *ox, rnd_coord_t *oy)
+{
+	const char *name = "openscad-origin";
+	pcb_data_it_t it;
+	pcb_any_obj_t *obj;
+
+	for(obj = pcb_data_first(&it, PCB->Data, PCB_OBJ_CLASS_REAL); obj != NULL; obj = pcb_data_next(&it)) {
+		if (pcb_attribute_get(&obj->Attributes, name) != NULL) {
+			pcb_obj_center(obj, ox, oy);
+			TRX(*ox); TRY(*oy);
+			return;
+		}
+	}
+}
+
 
 static void openscad_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
 	const char *filename;
 	int save_ons[PCB_MAX_LAYER];
 	pcb_cam_t cam;
+	rnd_coord_t ox = 0, oy = 0;
 
 	if (!options) {
 		openscad_get_export_options(hid, 0, design, appspec);
@@ -312,6 +336,22 @@ static void openscad_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_att
 	if (!filename)
 		filename = "pcb.openscad";
 
+	scad_prefix = options[HA_prefix].str;
+	if (scad_prefix == NULL)
+		scad_prefix = "pcb";
+
+	{
+		rnd_layergrp_id_t from = 0, to = 0;
+
+		pcb_layergrp_list(PCB, PCB_LYT_BOTTOM|PCB_LYT_COPPER, &from, 1);
+		pcb_layergrp_list(PCB, PCB_LYT_TOP|PCB_LYT_COPPER, &to, 1);
+
+		if (from != to)
+			board_thickness = RND_COORD_TO_MM(pcb_stack_thickness(PCB, "openscad", PCB_BRDTHICK_PRINT_ERROR, from, 1, to, 0, PCB_LYT_SUBSTRATE|PCB_LYT_COPPER));
+		else
+			board_thickness = 1.6;
+	}
+
 	pcb_cam_begin_nolayer(PCB, &cam, NULL, options[HA_cam].str, &filename);
 
 	f = rnd_fopen_askovr(&PCB->hidlib, filename, "wb", NULL);
@@ -341,7 +381,9 @@ static void openscad_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_att
 	if (options[HA_drill].lng)
 		scad_draw_drills();
 
-	scad_draw_finish(options);
+	find_origin(&ox, &oy);
+
+	scad_draw_finish(options, ox, oy);
 
 	pcb_hid_restore_layer_ons(save_ons);
 
@@ -493,7 +535,7 @@ static void openscad_fill_rect(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1,
 	TRX(x2); TRY(y2);
 
 	fix_rect_coords();
-	rnd_fprintf(f, "			pcb_fill_rect(%mm, %mm, %mm, %mm, %f, %f);\n",
+	rnd_fprintf(f, "			%s_fill_rect(%mm, %mm, %mm, %mm, %f, %f);\n", scad_prefix,
 		x1, y1, x2, y2, 0.0, effective_layer_thickness);
 }
 
@@ -513,7 +555,7 @@ static void openscad_draw_line(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1,
 	else
 		cap_style = "rc";
 
-	rnd_fprintf(f, "			pcb_line_%s(%mm, %mm, %mm, %f, %mm, %f);\n", cap_style,
+	rnd_fprintf(f, "			%s_line_%s(%mm, %mm, %mm, %f, %mm, %f);\n", scad_prefix, cap_style,
 		x1, y1, (rnd_coord_t)rnd_round(length), angle * RND_RAD_TO_DEG, gc->width, effective_layer_thickness);
 }
 
@@ -567,13 +609,13 @@ static void openscad_fill_circle(rnd_hid_gc_t gc, rnd_coord_t cx, rnd_coord_t cy
 {
 	TRX(cx); TRY(cy);
 
-	rnd_fprintf(f, "			pcb_fcirc(%mm, %mm, %mm, %f);\n", cx, cy, radius, effective_layer_thickness);
+	rnd_fprintf(f, "			%s_fcirc(%mm, %mm, %mm, %f);\n", scad_prefix, cx, cy, radius, effective_layer_thickness);
 }
 
 static void openscad_fill_polygon_offs(rnd_hid_gc_t gc, int n_coords, rnd_coord_t *x, rnd_coord_t *y, rnd_coord_t dx, rnd_coord_t dy)
 {
 	int n;
-	fprintf(f, "			pcb_fill_poly([");
+	fprintf(f, "			%s_fill_poly([", scad_prefix);
 	for(n = 0; n < n_coords-1; n++)
 		rnd_fprintf(f, "[%mm,%mm],", TRX_(x[n]+dx), TRY_(y[n]+dy));
 	rnd_fprintf(f, "[%mm,%mm]], %f);\n", TRX_(x[n]+dx), TRY_(y[n]+dy), effective_layer_thickness);
