@@ -431,6 +431,8 @@ void ps_hid_export_to_file(rnd_design_t *dsg, FILE * the_file, rnd_hid_attr_val_
 	rnd_ps_end_pages(&global.ps);
 
 	memcpy(pcb_layer_stack, saved_layer_stack, sizeof(pcb_layer_stack));
+
+	rnd_conf_update(NULL, -1); /* restore forced sets */
 }
 
 static void ps_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
@@ -505,6 +507,8 @@ static int ps_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 	return rnd_hid_parse_command_line(argc, argv);
 }
 
+extern int rnd_ps_faded;
+
 static int ps_set_layer_group(rnd_hid_t *hid, rnd_design_t *design, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
 {
 	gds_t tmp_ln;
@@ -524,7 +528,7 @@ static int ps_set_layer_group(rnd_hid_t *hid, rnd_design_t *design, rnd_layergrp
 			if (is_empty)
 				return 0;
 
-			if ((group >= 0) && pcb_layergrp_is_empty(PCB, group))
+			if ((group >= 0) && pcb_cam_layergrp_is_empty(&ps_cam, PCB, group))
 				return 0;
 		}
 
@@ -544,6 +548,7 @@ static int ps_set_layer_group(rnd_hid_t *hid, rnd_design_t *design, rnd_layergrp
 	global.is_assy = PCB_LAYER_IS_ASSY(flags, purpi);
 	global.is_copper = !!(flags & PCB_LYT_COPPER);
 	global.is_paste = !!(flags & PCB_LYT_PASTE);
+	rnd_ps_faded = ((xform != NULL) && (*xform != NULL) && (*xform)->layer_faded);
 
 #if 0
 	printf("Layer %s group %d drill %d mask %d\n", name, group, global.ps.is_drill, global.ps.is_mask);
