@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  pcb-rnd, interactive printed circuit board design
- *  Copyright (C) 2019,2020 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2019,2020,2023 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -90,7 +90,9 @@ static const rnd_export_opt_t stl_attribute_list[] = {
 
 #define NUM_OPTIONS (sizeof(stl_attribute_list)/sizeof(stl_attribute_list[0]))
 
-static rnd_hid_attr_val_t stl_values[NUM_OPTIONS];
+static rnd_hid_attr_val_t stl_values_[NUM_OPTIONS];
+static rnd_hid_attr_val_t amf_values_[NUM_OPTIONS];
+static rnd_hid_attr_val_t proj_values_[NUM_OPTIONS];
 
 static long pa_len(const rnd_polyarea_t *pa)
 {
@@ -259,10 +261,16 @@ static long estimate_cutout_pts(pcb_board_t *pcb, vtp0_t *cutouts, pcb_dynf_t df
 		int purpi = pcb_layer_purpose(pcb, lid, NULL);
 		pcb_layer_t *layer = &pcb->Data->Layer[lid];
 		pcb_poly_t *poly;
+		pcb_line_t *line;
+		pcb_arc_t *arc;
+		rnd_rtree_it_t it;
+		
 
 		if (!PCB_LAYER_IS_ROUTE(lyt, purpi)) continue;
 /*		rnd_trace("Outline [%ld]\n", lid);*/
-		PCB_LINE_LOOP(layer) {
+
+		if (layer->line_tree != NULL)
+		for(line = rnd_rtree_all_first(&it, layer->line_tree); line != NULL; line = rnd_rtree_all_next(&it)) {
 			if (PCB_DFLAG_TEST(&line->Flags, df)) continue; /* object already found - either as outline or as a cutout */
 			poly = pcb_topoly_conn_with(pcb, (pcb_any_obj_t *)line, PCB_TOPOLY_FLOATING, df);
 			if (poly != NULL) {
@@ -272,15 +280,18 @@ static long estimate_cutout_pts(pcb_board_t *pcb, vtp0_t *cutouts, pcb_dynf_t df
 			else
 				rnd_message(RND_MSG_ERROR, "Cutout error: need closed loops; cutout omitted\n(Hint: use the wireframe draw mode to see broken connections; use a coarse grid and snap to fix them up!)\n");
 /*			rnd_trace(" line: %ld %d -> %p\n", line->ID, PCB_DFLAG_TEST(&line->Flags, df), poly);*/
-		} PCB_END_LOOP;
-		PCB_ARC_LOOP(layer) {
+		}
+
+		if (layer->arc_tree != NULL)
+		for(arc = rnd_rtree_all_first(&it, layer->arc_tree); arc != NULL; arc = rnd_rtree_all_next(&it)) {
 			if (PCB_DFLAG_TEST(&arc->Flags, df)) continue; /* object already found - either as outline or as a cutout */
 			poly = pcb_topoly_conn_with(pcb, (pcb_any_obj_t *)arc, PCB_TOPOLY_FLOATING, df);
 			vtp0_append(cutouts, poly);
 			cnt += poly_len(poly);
 /*			rnd_trace(" arc: %ld %d -> %p\n", arc->ID, PCB_DFLAG_TEST(&arc->Flags, df), poly);*/
-		} PCB_END_LOOP;
+		}
 	}
+
 	return cnt;
 }
 
@@ -363,13 +374,13 @@ typedef struct {
 	stl_facet_t *(*model_load)(rnd_design_t *hl, FILE *f, const char *fn);
 } stl_fmt_t;
 
-static const rnd_export_opt_t *stl_get_export_options_(rnd_hid_t *hid, int *n, const stl_fmt_t *fmt, rnd_design_t *dsg, void *appspec)
+static const rnd_export_opt_t *stl_get_export_options_(rnd_hid_t *hid, int *n, const stl_fmt_t *fmt, rnd_hid_attr_val_t *values, rnd_design_t *dsg, void *appspec)
 {
 	const char *suffix = fmt->suffix;
-	const char *val = stl_values[HA_stlfile].str;
+	const char *val = values[HA_stlfile].str;
 
 	if ((dsg != NULL) && ((val == NULL) || (*val == '\0')))
-		pcb_derive_default_filename(dsg->loadname, &stl_values[HA_stlfile], suffix);
+		pcb_derive_default_filename(dsg->loadname, &values[HA_stlfile], suffix);
 
 	if (n)
 		*n = NUM_OPTIONS;
@@ -389,17 +400,17 @@ static const stl_fmt_t *fmt_all[] = {&fmt_amf, &fmt_stl, &fmt_proj, NULL};
 
 static const rnd_export_opt_t *stl_get_export_options(rnd_hid_t *hid, int *n, rnd_design_t *dsg, void *appspec)
 {
-	return stl_get_export_options_(hid, n, &fmt_stl, dsg, appspec);
+	return stl_get_export_options_(hid, n, &fmt_stl, stl_values_, dsg, appspec);
 }
 
 static const rnd_export_opt_t *amf_get_export_options(rnd_hid_t *hid, int *n, rnd_design_t *dsg, void *appspec)
 {
-	return stl_get_export_options_(hid, n, &fmt_amf, dsg, appspec);
+	return stl_get_export_options_(hid, n, &fmt_amf, amf_values_, dsg, appspec);
 }
 
 static const rnd_export_opt_t *proj_get_export_options(rnd_hid_t *hid, int *n, rnd_design_t *dsg, void *appspec)
 {
-	return stl_get_export_options_(hid, n, &fmt_proj, dsg, appspec);
+	return stl_get_export_options_(hid, n, &fmt_proj, proj_values_, dsg, appspec);
 }
 
 static int stl_hid_export_to_file(FILE *f, rnd_hid_attr_val_t *options, rnd_coord_t maxy, rnd_coord_t z0, rnd_coord_t z1, const stl_fmt_t *fmt)
@@ -442,7 +453,7 @@ static int stl_hid_export_to_file(FILE *f, rnd_hid_attr_val_t *options, rnd_coor
 	contlen = pa_len(brdpoly->Clipped);
 	mem_req = fp2t_memory_required(contlen + pstk_points + cutout_points);
 	mem = calloc(mem_req, 1);
-	if (!fp2t_init(&tri, mem, contlen + pstk_points)) {
+	if (!fp2t_init(&tri, mem, contlen + pstk_points + cutout_points)) {
 		free(mem);
 		pcb_poly_free(brdpoly);
 		pcb_dynflag_free(df);
@@ -512,9 +523,9 @@ static int stl_hid_export_to_file(FILE *f, rnd_hid_attr_val_t *options, rnd_coor
 
 	fmt->print_footer(f);
 
-	vtp0_uninit(&cutouts);
 	for(n = 0; n < cutouts.used; n++)
 		pcb_poly_free((pcb_poly_t *)cutouts.array[n]);
+	vtp0_uninit(&cutouts);
 	vtd0_uninit(&contours);
 	free(mem);
 	pcb_poly_free(brdpoly);
@@ -522,7 +533,7 @@ static int stl_hid_export_to_file(FILE *f, rnd_hid_attr_val_t *options, rnd_coor
 	return 0;
 }
 
-static void stl_do_export_(rnd_hid_t *hid, rnd_hid_attr_val_t *options, const stl_fmt_t *fmt, rnd_design_t *dsg, void *appspec)
+static void stl_do_export_(rnd_hid_t *hid, rnd_hid_attr_val_t *options, const stl_fmt_t *fmt, rnd_hid_attr_val_t *values, rnd_design_t *dsg, void *appspec)
 {
 	const char *filename;
 	pcb_cam_t cam;
@@ -530,8 +541,8 @@ static void stl_do_export_(rnd_hid_t *hid, rnd_hid_attr_val_t *options, const st
 	rnd_coord_t thick;
 
 	if (!options) {
-		stl_get_export_options_(hid, 0, fmt, dsg, appspec);
-		options = stl_values;
+		stl_get_export_options_(hid, 0, fmt, values, dsg, appspec);
+		options = values;
 	}
 
 	filename = options[HA_stlfile].str;
@@ -565,17 +576,17 @@ static void stl_do_export_(rnd_hid_t *hid, rnd_hid_attr_val_t *options, const st
 
 static void stl_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
-	stl_do_export_(hid, options, &fmt_stl, design, appspec);
+	stl_do_export_(hid, options, &fmt_stl, stl_values_, design, appspec);
 }
 
 static void amf_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
-	stl_do_export_(hid, options, &fmt_amf, design, appspec);
+	stl_do_export_(hid, options, &fmt_amf, amf_values_, design, appspec);
 }
 
 static void proj_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
-	stl_do_export_(hid, options, &fmt_proj, design, appspec);
+	stl_do_export_(hid, options, &fmt_proj, proj_values_, design, appspec);
 }
 
 static int stl_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
@@ -619,7 +630,7 @@ int pplg_init_export_stl(void)
 	stl_hid.get_export_options = stl_get_export_options;
 	stl_hid.do_export = stl_do_export;
 	stl_hid.parse_arguments = stl_parse_arguments;
-	stl_hid.argument_array = stl_values;
+	stl_hid.argument_array = stl_values_;
 
 	stl_hid.usage = stl_usage;
 
@@ -632,6 +643,7 @@ int pplg_init_export_stl(void)
 	amf_hid.description = "export board outline in 3-dimensional AMF";
 	amf_hid.get_export_options = amf_get_export_options;
 	amf_hid.do_export = amf_do_export;
+	amf_hid.argument_array = amf_values_;
 
 	rnd_hid_register_hid(&amf_hid);
 	rnd_hid_load_defaults(&amf_hid, stl_attribute_list, NUM_OPTIONS);
@@ -642,6 +654,7 @@ int pplg_init_export_stl(void)
 	proj_hid.description = "export board outline as a projector(1) object for 3d rendering";
 	proj_hid.get_export_options = proj_get_export_options;
 	proj_hid.do_export = proj_do_export;
+	proj_hid.argument_array = proj_values_;
 
 	rnd_hid_register_hid(&proj_hid);
 	rnd_hid_load_defaults(&proj_hid, stl_attribute_list, NUM_OPTIONS);
