@@ -37,9 +37,9 @@
 
 #include <librnd/core/actions.h>
 #include <librnd/core/plugins.h>
-#include <librnd/core/hid.h>
-#include <librnd/core/hid_dad.h>
-#include <librnd/core/hid_menu.h>
+#include <librnd/hid/hid.h>
+#include <librnd/hid/hid_dad.h>
+#include <librnd/hid/hid_menu.h>
 
 #include "ttf_load.h"
 #include "str_approx.h"
@@ -404,7 +404,7 @@ static void ttfgui_close_cb(void *caller_data, rnd_hid_attr_ev_t ev)
 	memset(ctx, 0, sizeof(ttfgui_ctx_t)); /* reset all states to the initial - includes ctx->active = 0; */
 }
 
-static void ttf_expose(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void ttf_expose(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 /*	ttfgui_ctx_t *ctx = prv->user_ctx;*/
 	char s[17];
@@ -585,8 +585,7 @@ fgw_error_t pcb_act_LoadTtf(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	RND_DAD_BEGIN_VBOX(ctx->dlg);
 		RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
 
-			RND_DAD_BEGIN_HPANE(ctx->dlg);
-				RND_DAD_SET_PANE_NAME(ctx->dlg, "left-right");
+			RND_DAD_BEGIN_HPANE(ctx->dlg, "left-right");
 				RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
 
 				/* left */
