@@ -45,7 +45,7 @@
 #include <librnd/core/error.h>
 #include <librnd/core/misc_util.h>
 #include <librnd/core/base64.h>
-#include <librnd/core/pixmap.h>
+#include <librnd/hid/pixmap.h>
 #include <libulzw/libulzw.h>
 #include "layer.h"
 #include <genvector/vtp0.h>
@@ -454,8 +454,8 @@ static int parse_meta(lht_read_t *rctx, pcb_board_t *pcb, lht_node_t *nd)
 
 	grp = lht_dom_hash_get(nd, "size");
 	if ((grp != NULL) && (grp->type == LHT_HASH)) {
-		err |= parse_coord(&pcb->hidlib.size_x, hash_get(grp, "x", 0));
-		err |= parse_coord(&pcb->hidlib.size_y, hash_get(grp, "y", 0));
+		err |= parse_coord(&pcb->hidlib.dwg.X2, hash_get(grp, "x", 0));
+		err |= parse_coord(&pcb->hidlib.dwg.Y2, hash_get(grp, "y", 0));
 		err |= parse_coord_conf(rctx, "design/poly_isle_area", hash_get(grp, "isle_area_nm2", 1));
 		err |= parse_double(&pcb->ThermScale, hash_get(grp, "thermal_scale", 1));
 		if (pcb->ThermScale < 0.01) {
@@ -2160,14 +2160,14 @@ static pcb_data_t *parse_data(lht_read_t *rctx, pcb_board_t *pcb, pcb_data_t *ds
 #define PARSE_COORD(dst, src)       parse_coord(dst, src)
 #define PARSE_DOUBLE(dst, src)      parse_double(dst, src)
 #define HASH_GET(hash, name)        hash_get(hash, name, 0)
-#define LHT_ERROR                   iolht_error
+#define RND_LHT_ERROR               iolht_error
 
-#include <rnd_inclib/font/font_lht.h>
+#include <librnd/font/font_lht.h>
 
 #undef PARSE_COORD
 #undef PARSE_DOUBLE
 #undef PARSE_HASH_GET
-#undef LHT_ERROR
+#undef RND_LHT_ERROR
 
 static int parse_fontkit(pcb_fontkit_t *fk, lht_node_t *nd)
 {
@@ -2444,7 +2444,7 @@ static void parse_conf(lht_read_t *rctx, pcb_board_t *pcb, lht_node_t *sub)
 	if (rctx->cfg_dest == RND_CFR_invalid)
 		return;
 	if (rnd_conf_insert_tree_as(rctx->cfg_dest, sub) != 0)
-		rnd_message(RND_MSG_ERROR, "Failed to insert the config subtree '%s' found in %s\n", sub->name, pcb->hidlib.filename);
+		rnd_message(RND_MSG_ERROR, "Failed to insert the config subtree '%s' found in %s\n", sub->name, pcb->hidlib.loadname);
 	else
 		rnd_conf_update(NULL, -1);
 }
