@@ -46,7 +46,7 @@
 #include "rats_patch.h"
 #include <librnd/core/actions.h>
 #include <librnd/core/base64.h>
-#include <librnd/core/pixmap.h>
+#include <librnd/hid/pixmap.h>
 #include <librnd/core/misc_util.h>
 #include "layer.h"
 #include "common.h"
@@ -60,7 +60,7 @@
 #include "thermal.h"
 #include "funchash_core.h"
 #include "netlist.h"
-#include <librnd/core/hid_dad.h>
+#include <librnd/hid/hid_dad.h>
 
 #include "src_plugins/lib_compat_help/pstk_compat.h"
 #include "src_plugins/lib_compat_help/route_style.h"
@@ -174,8 +174,11 @@ static lht_node_t *build_board_meta(pcb_board_t *pcb)
 
 	grp = lht_dom_node_alloc(LHT_HASH, "size");
 	lht_dom_hash_put(meta, grp);
-	lht_dom_hash_put(grp, build_textf("x", CFMT, pcb->hidlib.size_x));
-	lht_dom_hash_put(grp, build_textf("y", CFMT, pcb->hidlib.size_y));
+	lht_dom_hash_put(grp, build_textf("x", CFMT, pcb->hidlib.dwg.X2));
+	lht_dom_hash_put(grp, build_textf("y", CFMT, pcb->hidlib.dwg.Y2));
+	if ((pcb->hidlib.dwg.X1 != 0) || (pcb->hidlib.dwg.Y1 != 0))
+		pcb_io_incompat_save(NULL, NULL, "board", "drawing are bbox with non-zero origin (X1 or Y1)\n", "Run autocrop()");
+
 	if (wrver < 5) {
 		lht_dom_hash_put(grp, build_textf("isle_area_nm2", "%f", conf_core.design.poly_isle_area));
 	}
@@ -1847,8 +1850,8 @@ static int io_lihata_write_pcb(pcb_plug_io_t *ctx, FILE * FP, const char *old_fi
 			char *orig_fn, *end;
 			char *pcb_fn = rnd_strdup_subst(fnpat, rnd_build_fn_cb, &PCB->hidlib, RND_SUBST_ALL);
 			
-			orig_fn = PCB->hidlib.filename;
-			PCB->hidlib.filename = NULL;
+			orig_fn = PCB->hidlib.loadname;
+			PCB->hidlib.loadname = NULL;
 
 			/* avoid .lht.lht.pcb */
 			end = pcb_fn + strlen(pcb_fn) - 1;
@@ -1859,8 +1862,8 @@ static int io_lihata_write_pcb(pcb_plug_io_t *ctx, FILE * FP, const char *old_fi
 			free(pcb_fn);
 			
 			/* restore these because SaveTo() has changed them */
-			free(PCB->hidlib.filename);
-			PCB->hidlib.filename = orig_fn;
+			free(PCB->hidlib.loadname);
+			PCB->hidlib.loadname = orig_fn;
 			PCB->Data->loader = ctx;
 		}
 	}
