@@ -31,7 +31,7 @@
 
 #include "config.h"
 #include "conf_core.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 
 #include <locale.h>
 #include <time.h>
@@ -46,7 +46,7 @@
 #include <librnd/core/error.h>
 #include "file.h"
 #include "plug_io.h"
-#include <librnd/core/hid.h>
+#include <librnd/hid/hid.h>
 #include "layer.h"
 #include "layer_grp.h"
 #include "move.h"
@@ -293,7 +293,7 @@ static void WritePCBDataHeader(FILE * FP)
 
 	fputs("\nPCB[", FP);
 	pcb_print_quoted_string(FP, (char *) RND_EMPTY(PCB->hidlib.name));
-	rnd_fprintf(FP, " %[0] %[0]]\n\n", PCB->hidlib.size_x, PCB->hidlib.size_y);
+	rnd_fprintf(FP, " %[0] %[0]]\n\n", PCB->hidlib.dwg.X2, PCB->hidlib.dwg.Y2);
 	rnd_fprintf(FP, "Grid[%[0] %[0] %[0] %d]\n", PCB->hidlib.grid, PCB->hidlib.grid_ox, PCB->hidlib.grid_oy, rnd_conf.editor.draw_grid);
 	rnd_fprintf(FP, "Cursor[%[0] %[0] 1000]\n", pcb_crosshair.X, pcb_crosshair.Y);
 	/* PolyArea should be output in square cmils, no suffix */
@@ -835,8 +835,8 @@ void PostLoadElementPCB()
 	pcb_data_bbox(&dbb, yyPCB->Data, rnd_false);
 	pcb_data_normalize_(yyPCB->Data, &dbb);
 	PCB = pcb_save;
-	yyPCB->hidlib.size_x = dbb.X2*2;
-	yyPCB->hidlib.size_y = dbb.Y2*2;
+	yyPCB->hidlib.dwg.X2 = dbb.X2*2;
+	yyPCB->hidlib.dwg.Y2 = dbb.Y2*2;
 	yyPCB->is_footprint = 1;
 
 	/* opening a footprint: we don't have a layer stack; make sure top and bottom copper exist */
