@@ -28,7 +28,7 @@
  */
 
 #include "config.h"
-#include "plugins.h"
+#include <librnd/core/plugins.h>
 #include "parse_common.h"
 #include "file.h"
 
@@ -57,22 +57,23 @@ void pplg_uninit_io_pcb(void)
 	pcb_lex_destroy();
 
 	for(n = 0; n < 3; n++)
-		PCB_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &(io_pcb[n]));
+		RND_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &(io_pcb[n]));
 }
 
 int pplg_init_io_pcb(void)
 {
-	PCB_API_CHK_VER;
+	RND_API_CHK_VER;
 
 	memset(&io_pcb, 0, sizeof(io_pcb));
 
 	/* register the IO hook */
-	ctx[0].write_coord_fmt = pcb_printf_slot[8];
+	ctx[0].write_coord_fmt = rnd_printf_slot[8];
 	io_pcb[0].plugin_data = &ctx[0];
 	io_pcb[0].fmt_support_prio = io_pcb_fmt;
 	io_pcb[0].test_parse = io_pcb_test_parse;
 	io_pcb[0].parse_pcb = io_pcb_ParsePCB;
 	io_pcb[0].parse_footprint = io_pcb_ParseElement;
+	io_pcb[0].map_footprint = io_pcb_map_footprint; /* it is enough to have this in [0] so the same checks are not done multiple times, per version */
 	io_pcb[0].parse_font = io_pcb_ParseFont;
 	io_pcb[0].write_buffer = NULL;
 	io_pcb[0].write_subcs_head = io_pcb_write_subcs_head;
@@ -85,10 +86,10 @@ int pplg_init_io_pcb(void)
 	io_pcb[0].default_extension = ".pcb";
 	io_pcb[0].fp_extension = ".fp";
 	io_pcb[0].mime_type = "application/x-pcb-layout";
-	PCB_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &(io_pcb[0]));
+	RND_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &(io_pcb[0]));
 	pcb_centimil_io_pcb = &io_pcb[0];
 
-	ctx[1].write_coord_fmt = pcb_printf_slot[9];
+	ctx[1].write_coord_fmt = rnd_printf_slot[9];
 	io_pcb[1].plugin_data = &ctx[1];
 	io_pcb[1].fmt_support_prio = io_pcb_fmt;
 	io_pcb[1].write_buffer = NULL;
@@ -102,7 +103,7 @@ int pplg_init_io_pcb(void)
 	io_pcb[1].default_extension = ".pcb";
 	io_pcb[1].fp_extension = ".fp";
 	io_pcb[1].mime_type = "application/x-pcb-layout";
-	PCB_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &(io_pcb[1]));
+	RND_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &(io_pcb[1]));
 	pcb_preferred_io_pcb = &io_pcb[1];
 
 	ctx[2].write_coord_fmt = "%$$mn";
@@ -119,7 +120,7 @@ int pplg_init_io_pcb(void)
 	io_pcb[2].default_extension = ".pcb";
 	io_pcb[2].fp_extension = ".fp";
 	io_pcb[2].mime_type = "application/x-pcb-layout";
-	PCB_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &(io_pcb[2]));
+	RND_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &(io_pcb[2]));
 	pcb_nanometer_io_pcb = &io_pcb[2];
 
 
