@@ -44,11 +44,11 @@
 #include "netlist.h"
 #include <librnd/core/plugins.h>
 #include "plug_io.h"
-#include <librnd/core/hid.h>
+#include <librnd/hid/hid.h>
 #include "hid_cam.h"
-#include <librnd/core/hid_nogui.h>
-#include <librnd/core/hid_init.h>
-#include <librnd/core/hid_attrib.h>
+#include <librnd/hid/hid_nogui.h>
+#include <librnd/hid/hid_init.h>
+#include <librnd/hid/hid_attrib.h>
 
 static const char *sides(pcb_layer_type_t lyt)
 {
@@ -187,25 +187,25 @@ static rnd_hid_attr_val_t tedax_etest_values[NUM_OPTIONS];
 
 static const char *tedax_etest_filename;
 
-static const rnd_export_opt_t *tedax_etest_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *tedax_etest_get_export_options(rnd_hid_t *hid, int *n, rnd_design_t *dsg, void *appspec)
 {
 	const char *val = tedax_etest_values[HA_outfile].str;
-	if ((PCB != NULL) && (val == NULL))
-		pcb_derive_default_filename(PCB->hidlib.filename, &tedax_etest_values[HA_outfile], ".etest.tdx");
+	if ((dsg != NULL) && (val == NULL))
+		pcb_derive_default_filename(dsg->loadname, &tedax_etest_values[HA_outfile], ".etest.tdx");
 
 	if (n)
 		*n = NUM_OPTIONS;
 	return tedax_etest_options;
 }
 
-static void tedax_etest_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+static void tedax_etest_do_export(rnd_hid_t *hid, rnd_design_t *design, rnd_hid_attr_val_t *options, void *appspec)
 {
 	int i;
 	const char *name;
 	pcb_cam_t cam;
 
 	if (!options) {
-		tedax_etest_get_export_options(hid, 0);
+		tedax_etest_get_export_options(hid, 0, design, appspec);
 		for (i = 0; i < NUM_OPTIONS; i++)
 			tedax_etest_values[i] = tedax_etest_options[i].default_val;
 		options = tedax_etest_values;
@@ -219,7 +219,7 @@ static void tedax_etest_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 
 	name = PCB->hidlib.name;
-	if (name == NULL) name = PCB->hidlib.filename;
+	if (name == NULL) name = PCB->hidlib.loadname;
 	if (name == NULL) name = "-";
 	tedax_etest_save(PCB,  name, tedax_etest_filename);
 	pcb_cam_end(&cam);
