@@ -20,7 +20,7 @@
 #include "config.h"
 #include "board.h"
 #include "data.h"
-#include <librnd/core/hid.h>
+#include <librnd/hid/hid.h>
 #include <librnd/poly/rtree.h>
 #include "undo.h"
 #include "polygon.h"
@@ -110,10 +110,10 @@ static void Debugpcb_polyarea_t(rnd_polyarea_t * s, char *color)
 		}
 	} while ((p = p->f) != s);
 /*	ddraw->flush_debug_draw();*/
-/*	rnd_hid_busy(PCB, 1); */
+/*	rnd_hid_busy(&PCB->hidlib, 1); */
 /*	sleep(3);
 	ddraw->finish_debug_draw();*/
-/*	rnd_hid_busy(PCB, 0); */
+/*	rnd_hid_busy(&PCB->hidlib, 0); */
 }
 
 /* Find the bounding box of a rnd_polyarea_t.
