@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  pcb-rnd, interactive printed circuit board design
- *  Copyright (C) 2016,2018,2019,2020 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2016,2018,2019,2020,2023 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -457,10 +457,17 @@ static void set_attr_raw(pcb_propset_ctx_t *st, pcb_attribute_list_t *list)
 	}
 
 	orig = pcb_attribute_get(list, key);
-	if ((orig != NULL) && (strcmp(orig, st->s) == 0))
-		return;
-
-	pcb_attribute_put(list, key, st->s);
+	if (st->arename) {
+		if (strcmp(st->s, key) == 0)
+			return;
+		pcb_attribute_put(list, st->s, orig);
+		pcb_attribute_remove(list, key);
+	}
+	else {
+		if ((orig != NULL) && (strcmp(orig, st->s) == 0))
+			return;
+		pcb_attribute_put(list, key, st->s);
+	}
 	st->set_cnt++;
 }
 
@@ -469,6 +476,9 @@ static void set_attr_obj(pcb_propset_ctx_t *st, pcb_any_obj_t *obj)
 	const char *key = st->name+2;
 	int side_effect, res;
 
+	if (st->arename && (strcmp(st->s, key) == 0))
+			return;
+
 	if (st->toggle) {
 		toggle_attr(st, &obj->Attributes, 1, obj);
 		return;
@@ -478,7 +488,20 @@ static void set_attr_obj(pcb_propset_ctx_t *st, pcb_any_obj_t *obj)
 
 	if (side_effect)
 		pcb_obj_pre(obj);
-	res = pcb_uchg_attr(st->pcb, obj, key, st->s);
+
+	if (st->arename) {
+		const char *orig = pcb_attribute_get(&obj->Attributes, key);
+		if (orig != NULL) {
+			res = pcb_uchg_attr(st->pcb, obj, st->s, orig);
+			if (res == 0)
+				res = pcb_uchg_attr(st->pcb, obj, key, NULL);
+		}
+		else
+			res = -1;
+	}
+	else
+		res = pcb_uchg_attr(st->pcb, obj, key, st->s);
+
 	if (side_effect) {
 		pcb_obj_update_bbox(st->pcb, obj);
 		pcb_obj_post(obj);
@@ -670,25 +693,37 @@ static void set_line(pcb_propset_ctx_t *st, pcb_line_t *line)
 		op.move.pcb = st->pcb;
 		pn = st->name + 7;
 		if (st->c_valid && (strcmp(pn, "x1") == 0)) {
-			op.move.dx = st->c - line->Point1.X;
+			if (st->c_absolute)
+				op.move.dx = st->c - line->Point1.X;
+			else
+				op.move.dx = st->c;
 			pcb_undo_add_obj_to_move(PCB_OBJ_LINE_POINT, line->parent.layer, line, &line->Point1, op.move.dx, op.move.dy);
 			if (pcb_lineop_move_point(&op, line->parent.layer, line, &line->Point1) != NULL)
 				DONE;
 		}
 		if (st->c_valid && (strcmp(pn, "y1") == 0)) {
-			op.move.dy = st->c - line->Point1.Y;
+			if (st->c_absolute)
+				op.move.dy = st->c - line->Point1.Y;
+			else
+				op.move.dy = st->c;
 			pcb_undo_add_obj_to_move(PCB_OBJ_LINE_POINT, line->parent.layer, line, &line->Point1, op.move.dx, op.move.dy);
 			if (pcb_lineop_move_point(&op, line->parent.layer, line, &line->Point1) != NULL)
 				DONE;
 		}
 		if (st->c_valid && (strcmp(pn, "x2") == 0)) {
-			op.move.dx = st->c - line->Point2.X;
+			if (st->c_absolute)
+				op.move.dx = st->c - line->Point2.X;
+			else
+				op.move.dx = st->c;
 			pcb_undo_add_obj_to_move(PCB_OBJ_LINE_POINT, line->parent.layer, line, &line->Point2, op.move.dx, op.move.dy);
 			if (pcb_lineop_move_point(&op, line->parent.layer, line, &line->Point2) != NULL)
 				DONE;
 		}
 		if (st->c_valid && (strcmp(pn, "y2") == 0)) {
-			op.move.dy = st->c - line->Point2.Y;
+			if (st->c_absolute)
+				op.move.dy = st->c - line->Point2.Y;
+			else
+				op.move.dy = st->c;
 			pcb_undo_add_obj_to_move(PCB_OBJ_LINE_POINT, line->parent.layer, line, &line->Point2, op.move.dx, op.move.dy);
 			if (pcb_lineop_move_point(&op, line->parent.layer, line, &line->Point2) != NULL)
 				DONE;
@@ -739,13 +774,19 @@ static void set_arc(pcb_propset_ctx_t *st, pcb_arc_t *arc)
 		op.move.pcb = st->pcb;
 		pn = st->name + 6;
 		if (st->c_valid && (strcmp(pn, "x") == 0)) {
-			op.move.dx = st->c - arc->X;
+			if (st->c_absolute)
+				op.move.dx = st->c - arc->X;
+			else
+				op.move.dx = st->c;
 			pcb_undo_add_obj_to_move(PCB_OBJ_ARC, arc->parent.layer, arc, arc, op.move.dx, op.move.dy);
 			if (pcb_arcop_move(&op, arc->parent.layer, arc) != NULL)
 				DONE;
 		}
 		if (st->c_valid && (strcmp(pn, "y") == 0)) {
-			op.move.dy = st->c - arc->Y;
+			if (st->c_absolute)
+				op.move.dy = st->c - arc->Y;
+			else
+				op.move.dy = st->c;
 			pcb_undo_add_obj_to_move(PCB_OBJ_ARC, arc->parent.layer, arc, arc, op.move.dx, op.move.dy);
 			if (pcb_arcop_move(&op, arc->parent.layer, arc) != NULL)
 				DONE;
@@ -830,13 +871,19 @@ static void set_text(pcb_propset_ctx_t *st, pcb_text_t *text)
 		memset(&op, 0, sizeof(op));
 		op.move.pcb = st->pcb;
 		if (st->c_valid && (strcmp(pn, "x") == 0)) {
-			op.move.dx = st->c - text->X;
+			if (st->c_absolute)
+				op.move.dx = st->c - text->X;
+			else
+				op.move.dx = st->c;
 			pcb_undo_add_obj_to_move(PCB_OBJ_TEXT, text->parent.layer, text, text, op.move.dx, op.move.dy);
 			if (pcb_textop_move(&op, text->parent.layer, text) != NULL)
 				DONE;
 		}
 		if (st->c_valid && (strcmp(pn, "y") == 0)) {
-			op.move.dy = st->c - text->Y;
+			if (st->c_absolute)
+				op.move.dy = st->c - text->Y;
+			else
+				op.move.dy = st->c;
 			pcb_undo_add_obj_to_move(PCB_OBJ_TEXT, text->parent.layer, text, text, op.move.dx, op.move.dy);
 			if (pcb_textop_move(&op, text->parent.layer, text) != NULL)
 				DONE;
@@ -941,13 +988,19 @@ static void set_pstk(pcb_propset_ctx_t *st, pcb_pstk_t *ps)
 		memset(&op, 0, sizeof(op));
 		op.move.pcb = st->pcb;
 		if (st->c_valid && (strcmp(pn, "x") == 0)) {
-			op.move.dx = st->c - ps->x;
+			if (st->c_absolute)
+				op.move.dx = st->c - ps->x;
+			else
+				op.move.dx = st->c;
 			pcb_undo_add_obj_to_move(PCB_OBJ_PSTK, ps->parent.data, ps, ps, op.move.dx, op.move.dy);
 			if (pcb_pstkop_move(&op, ps) != NULL)
 				DONE;
 		}
 		if (st->c_valid && (strcmp(pn, "y") == 0)) {
-			op.move.dy = st->c - ps->y;
+			if (st->c_absolute)
+				op.move.dy = st->c - ps->y;
+			else
+				op.move.dy = st->c;
 			pcb_undo_add_obj_to_move(PCB_OBJ_PSTK, ps->parent.data, ps, ps, op.move.dx, op.move.dy);
 			if (pcb_pstkop_move(&op, ps) != NULL)
 				DONE;
@@ -1004,13 +1057,19 @@ static void set_subc(pcb_propset_ctx_t *st, pcb_subc_t *ssubc)
 		memset(&op, 0, sizeof(op));
 		op.move.pcb = st->pcb;
 		if (st->c_valid && (strcmp(pn, "x") == 0)) {
-			op.move.dx = st->c - x;
+			if (st->c_absolute)
+				op.move.dx = st->c - x;
+			else
+				op.move.dx = st->c;
 			pcb_undo_add_obj_to_move(PCB_OBJ_SUBC, ssubc->parent.data, ssubc, ssubc, op.move.dx, op.move.dy);
 			if (pcb_subcop_move(&op, ssubc) != NULL)
 				DONE;
 		}
 		if (st->c_valid && (strcmp(pn, "y") == 0)) {
-			op.move.dy = st->c - y;
+			if (st->c_absolute)
+				op.move.dy = st->c - y;
+			else
+				op.move.dy = st->c;
 			pcb_undo_add_obj_to_move(PCB_OBJ_SUBC, ssubc->parent.data, ssubc, ssubc, op.move.dx, op.move.dy);
 			if (pcb_subcop_move(&op, ssubc) != NULL)
 				DONE;
@@ -1086,18 +1145,21 @@ int pcb_propsel_set(pcb_propedit_t *ctx, const char *prop, pcb_propset_ctx_t *sc
 
 int pcb_propsel_set_str(pcb_propedit_t *ctx, const char *prop, const char *value)
 {
-	pcb_propset_ctx_t sctx;
+	pcb_propset_ctx_t sctx = {0};
 	char *end;
 	const char *start;
 
+	if ((prop[0] == 'r') && (strncmp(prop, "rename/a/", 9)) == 0) {
+		sctx.arename = 1;
+		prop += 7;
+	}
+
 	/* sanity checks for invalid props */
 	if ((prop[1] != '/') || ((prop[0] != 'a') && (prop[0] != 'p'))) {
 		rnd_message(RND_MSG_ERROR, "Invalid property path: '%s':\n must start with p/ for property or a/ for attribute\n", prop);
 		return 0;
 	}
 
-	memset(&sctx, 0, sizeof(sctx));
-
 	if (value == NULL)
 		value = "";
 	sctx.s = value;
