@@ -33,7 +33,7 @@
 #include "config.h"
 
 #include "conf_core.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 #include "src_plugins/query/net_len.h"
 
 #include <math.h>
@@ -64,7 +64,7 @@
 #include "obj_pstk.h"
 #include "obj_pstk_inlines.h"
 #include "obj_subc_parent.h"
-#include <librnd/core/hid_dad.h>
+#include <librnd/hid/hid_dad.h>
 #include "netlist.h"
 
 #include <genregex/regex_sei.h>
@@ -800,12 +800,12 @@ static fgw_error_t pcb_act_Report(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 static fgw_error_t pcb_act_info(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	int i, j;
-	if (!PCB || !PCB->Data || !PCB->hidlib.filename) {
+	if (!PCB || !PCB->Data || !PCB->hidlib.loadname) {
 		printf("No PCB loaded.\n");
 		return 0;
 	}
-	printf("Filename: %s\n", PCB->hidlib.filename);
-	rnd_printf("Size: %ml x %ml mils, %mm x %mm mm\n", PCB->hidlib.size_x, PCB->hidlib.size_y, PCB->hidlib.size_x, PCB->hidlib.size_y);
+	printf("Filename: %s\n", PCB->hidlib.loadname);
+	rnd_printf("Size: %ml x %ml mils, %mm x %mm mm\n", rnd_dwg_get_size_x(&PCB->hidlib), rnd_dwg_get_size_y(&PCB->hidlib), rnd_dwg_get_size_x(&PCB->hidlib), rnd_dwg_get_size_y(&PCB->hidlib));
 	for (i = 0; i < PCB_MAX_LAYER; i++) {
 		rnd_layergrp_id_t lg = pcb_layer_get_group(PCB, i);
 		unsigned int gflg = pcb_layergrp_flags(PCB, lg);
@@ -930,6 +930,8 @@ static fgw_error_t pcb_act_NetLength(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		rnd_hid_get_coords("Click on an object for net length measurement", &x, &y, 0);
 
 		type = pcb_search_screen(x, y, PCB_OBJ_LINE | PCB_OBJ_ARC | PCB_OBJ_PSTK, &p1, &p2, &p3);
+		if (type == PCB_OBJ_VOID) /* fall back to subc parts */
+			type = pcb_search_screen(x, y, PCB_OBJ_LINE | PCB_OBJ_ARC | PCB_OBJ_PSTK | PCB_OBJ_SUBC_PART, &p1, &p2, &p3);
 		if (type == PCB_OBJ_VOID)
 			goto error;
 
