@@ -43,8 +43,8 @@
 #include "obj_poly.h"
 #include "obj_poly_draw.h"
 #include "rotate.h"
-#include <librnd/core/tool.h>
-#include <librnd/core/hid_menu.h>
+#include <librnd/hid/tool.h>
+#include <librnd/hid/hid_menu.h>
 #include "menu_internal.c"
 
 const char *pcb_shape_corner_name[] = {"Rn", "Ch", "Sq", NULL};
@@ -631,7 +631,7 @@ fgw_error_t pcb_act_circle(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		return 0;
 	}
 
-	if ((dia < 1) || (dia > (PCB->hidlib.size_x + PCB->hidlib.size_y)/4)) {
+	if ((dia < 1) || (dia > (rnd_dwg_get_size_x(&PCB->hidlib) + rnd_dwg_get_size_y(&PCB->hidlib))/4)) {
 		rnd_message(RND_MSG_ERROR, "circle(): invalid diameter\n");
 		RND_ACT_IRES(1);
 		return 0;
