@@ -28,7 +28,9 @@
 
 #include <librnd/core/plugins.h>
 #include <librnd/core/actions.h>
-#include <librnd/core/hid_menu.h>
+#include <librnd/hid/hid_menu.h>
+#include <librnd/core/hidlib.h>
+#include <librnd/core/conf_multi.h>
 #include <genht/htpp.h>
 #include <genht/hash.h>
 
@@ -140,12 +142,12 @@ static void show_netnames_invalidate(void)
 	pcb_qry_uninit(&shn_qctx);
 }
 
-static void show_netnames_inv_cache(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void show_netnames_inv_cache(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	shn_cache_uptodate = 0;
 }
 
-static void show_netnames_brd_chg(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void show_netnames_brd_chg(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	if (conf_show_netnames.plugins.show_netnames.enable)
 		show_netnames_invalidate();
@@ -246,7 +248,7 @@ static void *shn_render_cb(void *ctx, pcb_any_obj_t *obj)
 	return NULL;
 }
 
-static void show_netnames_render(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void show_netnames_render(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	pcb_board_t *pcb;
 	pcb_draw_info_t *info;
@@ -278,11 +280,10 @@ void pplg_uninit_show_netnames(void)
 {
 	show_netnames_invalidate();
 
-	rnd_conf_unreg_intern(show_netnames_conf_internal);
 	rnd_hid_menu_unload(rnd_gui, pcb_show_netnames_cookie);
 	rnd_event_unbind_allcookie(pcb_show_netnames_cookie);
 	rnd_remove_actions_by_cookie(pcb_show_netnames_cookie);
-	rnd_conf_unreg_fields("plugins/show_netnames/");
+	rnd_conf_plug_unreg("plugins/show_netnames/", show_netnames_conf_internal, pcb_show_netnames_cookie);
 
 	if (shn_cache_inited)
 		htshn_uninit(&shn_cache);
@@ -292,14 +293,13 @@ int pplg_init_show_netnames(void)
 {
 	RND_API_CHK_VER;
 
-	rnd_conf_reg_intern(show_netnames_conf_internal);
-
+	rnd_conf_plug_reg(conf_show_netnames, show_netnames_conf_internal, pcb_show_netnames_cookie);
 #define conf_reg(field,isarray,type_name,cpath,cname,desc,flags) \
 	rnd_conf_reg_field(conf_show_netnames, field,isarray,type_name,cpath,cname,desc,flags);
 #include "show_netnames_conf_fields.h"
 
 	rnd_event_bind(PCB_EVENT_BOARD_EDITED, show_netnames_brd_chg, NULL, pcb_show_netnames_cookie);
-	rnd_event_bind(RND_EVENT_BOARD_CHANGED, show_netnames_brd_chg, NULL, pcb_show_netnames_cookie);
+	rnd_event_bind(RND_EVENT_DESIGN_SET_CURRENT, show_netnames_brd_chg, NULL, pcb_show_netnames_cookie);
 	rnd_event_bind(RND_EVENT_GUI_DRAW_OVERLAY_XOR, show_netnames_render, NULL, pcb_show_netnames_cookie);
 	rnd_event_bind(PCB_EVENT_NETLIST_CHANGED, show_netnames_inv_cache, NULL, pcb_show_netnames_cookie);
 	rnd_event_bind(PCB_EVENT_FONT_CHANGED, show_netnames_inv_cache, NULL, pcb_show_netnames_cookie);
