@@ -45,7 +45,7 @@
 #include "obj_subc_parent.h"
 #include <librnd/core/rnd_printf.h>
 #include "search.h"
-#include <librnd/core/tool.h>
+#include <librnd/hid/tool.h>
 #include "layer_ui.h"
 #include "netlist.h"
 
@@ -695,7 +695,7 @@ static void sketch_create_for_layer(sketch_t *sk, pcb_layer_t *layer)
 	char name[256];
 
 	sk->cdt = malloc(sizeof(cdt_t));
-	cdt_init(sk->cdt, 0, 0, PCB->hidlib.size_x, -PCB->hidlib.size_y);
+	cdt_init(sk->cdt, 0, 0, PCB->hidlib.dwg.X2, -PCB->hidlib.dwg.Y2);
 	htpp_init(&sk->terminals, ptrhash, ptrkeyeq);
 	sk->wires.elem_constructor = vtwire_constructor;
 	sk->wires.elem_destructor = vtwire_destructor;
@@ -708,7 +708,7 @@ static void sketch_create_for_layer(sketch_t *sk, pcb_layer_t *layer)
 
 	sk->spoke_tree = rnd_r_create_tree();
 
-	bbox.X1 = 0; bbox.Y1 = 0; bbox.X2 = PCB->hidlib.size_x; bbox.Y2 = PCB->hidlib.size_y;
+	bbox.X1 = PCB->hidlib.dwg.X1; bbox.Y1 = PCB->hidlib.dwg.Y1; bbox.X2 = PCB->hidlib.dwg.X2; bbox.Y2 = PCB->hidlib.dwg.Y2;
 	info.layer = layer;
 	info.sk = sk;
 	rnd_r_search(PCB->Data->padstack_tree, &bbox, NULL, r_search_cb, &info, NULL);
@@ -787,7 +787,7 @@ static void sketches_uninit()
 
 
 /*** sketch line tool ***/
-static void tool_skline_adjust_attached_objects(rnd_hidlib_t *hl);
+static void tool_skline_adjust_attached_objects(rnd_design_t *hl);
 
 struct {
 	pcb_any_obj_t *start_term;
@@ -1018,7 +1018,7 @@ static void tool_skline_uninit(void)
 	rnd_hid_notify_crosshair_change(&PCB->hidlib, rnd_true);
 }
 
-static void tool_skline_notify_mode(rnd_hidlib_t *hl)
+static void tool_skline_notify_mode(rnd_design_t *hl)
 {
 	int type;
 	void *ptr1, *ptr2, *ptr3;
@@ -1070,7 +1070,7 @@ static void tool_skline_notify_mode(rnd_hidlib_t *hl)
 	}
 }
 
-static void tool_skline_adjust_attached_objects(rnd_hidlib_t *hl)
+static void tool_skline_adjust_attached_objects(rnd_design_t *hl)
 {
 	int last = vtp0_len(&attached_path.lines) - 1;
 	if (last >= 0) {
@@ -1079,7 +1079,7 @@ static void tool_skline_adjust_attached_objects(rnd_hidlib_t *hl)
 	}
 }
 
-static void tool_skline_draw_attached(rnd_hidlib_t *hl)
+static void tool_skline_draw_attached(rnd_design_t *hl)
 {
 	int i;
 	if (pcb_crosshair.AttachedObject.Type != PCB_OBJ_VOID) {
@@ -1091,7 +1091,7 @@ static void tool_skline_draw_attached(rnd_hidlib_t *hl)
 	}
 }
 
-rnd_bool tool_skline_undo_act(rnd_hidlib_t *hl)
+rnd_bool tool_skline_undo_act(rnd_design_t *hl)
 {
 	/* TODO */
 	return rnd_false;
