@@ -36,7 +36,7 @@
 #include "../src/plug_footprint.h"
 #include <librnd/core/conf.h>
 #include "../src/conf_core.h"
-#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/rnd_conf.h>
 #include "../src_3rd/qparse/qparse.h"
 #include "../config.h"
 #include <librnd/core/error.h>
@@ -46,7 +46,7 @@
 #include <librnd/core/misc_util.h>
 #include <librnd/core/safe_fs.h>
 #include <librnd/core/file_loaded.h>
-#include <librnd/core/hid_init.h>
+#include <librnd/hid/hid_init.h>
 #include "method.h"
 #include "help.h"
 #include "gsch2pcb_rnd_conf.h"
@@ -385,6 +385,7 @@ void gsch2pcb_conf_core_init(void) {}
 int main(int argc, char ** argv)
 {
 	const char *want_method;
+	char *exec_prefix;
 
 	method_import_register();
 
@@ -397,7 +398,11 @@ int main(int argc, char ** argv)
 	rnd_app.conf_sysdir_path = PCBCONFDIR;
 	rnd_app.conf_sys_path = rnd_concat(PCBCONFDIR, "/conf_core.lht", NULL);
 
-	rnd_hidlib_init1(gsch2pcb_conf_core_init);
+	exec_prefix = rnd_exec_prefix(argv[0], BINDIR, BINDIR_TO_EXECPREFIX);
+	rnd_hidlib_init1(gsch2pcb_conf_core_init, exec_prefix);
+	free(exec_prefix);
+
+	rnd_units_init();
 
 	rnd_file_loaded_init();
 	rnd_conf_init();
@@ -500,5 +505,6 @@ int main(int argc, char ** argv)
 	free_strlist(&extra_gnetlist_arg_list);
 	free_strlist(&extra_gnetlist_list);
 
+	rnd_units_uninit();
 	return 0;
 }
